Class: Google::Cloud::CloudSecurityCompliance::V1::AggregateFrameworkComplianceReportRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb

Overview

The request message for [AggregateFrameworkComplianceReport][].

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. The filtering results.

Returns:

  • (::String)

    Optional. The filtering results.



205
206
207
208
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 205

class AggregateFrameworkComplianceReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#interval::Google::Type::Interval

Returns Optional. The start and end time range for the aggregated compliance report.

Returns:



205
206
207
208
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 205

class AggregateFrameworkComplianceReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the aggregated compliance report over time to retrieve.

The supported format is: organizations/{organization_id}/locations/{location}/frameworkComplianceReports/{framework_compliance_report}.

Returns:

  • (::String)

    Required. The name of the aggregated compliance report over time to retrieve.

    The supported format is: organizations/{organization_id}/locations/{location}/frameworkComplianceReports/{framework_compliance_report}



205
206
207
208
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 205

class AggregateFrameworkComplianceReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end