Class: Google::Cloud::CloudSecurityCompliance::V1::AttributeSubstitutionRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb

Overview

The attribute at the given path that's substituted entirely.

Instance Attribute Summary collapse

Instance Attribute Details

#attribute::String

Returns The fully qualified proto attribute path, in dot notation. For example: rules[0].cel_expression.resource_types_values.

Returns:

  • (::String)

    The fully qualified proto attribute path, in dot notation. For example: rules[0].cel_expression.resource_types_values



389
390
391
392
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 389

class AttributeSubstitutionRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end