Class: Google::Cloud::CloudSecurityCompliance::V1::BucketDestination

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb

Overview

A Cloud Storage bucket destination.

Defined Under Namespace

Modules: Format

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_uri::String

Returns Required. The URI of the Cloud Storage bucket.

Returns:

  • (::String)

    Required. The URI of the Cloud Storage bucket.



133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 133

class BucketDestination
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The set of options for the framework audit format.
  module Format
    # Default value. This value is unused.
    FORMAT_UNSPECIFIED = 0

    # The format for the framework audit report is Open Document.
    ODF = 1
  end
end

#framework_audit_format::Google::Cloud::CloudSecurityCompliance::V1::BucketDestination::Format

Returns Optional. The format of the framework audit.

Returns:



133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 133

class BucketDestination
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The set of options for the framework audit format.
  module Format
    # Default value. This value is unused.
    FORMAT_UNSPECIFIED = 0

    # The format for the framework audit report is Open Document.
    ODF = 1
  end
end