Module: Google::Cloud::CloudSecurityCompliance::V1::BucketDestination::Format

Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb

Overview

The set of options for the framework audit format.

Constant Summary collapse

FORMAT_UNSPECIFIED =

Default value. This value is unused.

0
ODF =

The format for the framework audit report is Open Document.

1