Class: Google::Cloud::CloudSecurityCompliance::V1::CalculateEffectiveCmEnrollmentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb

Overview

The request message for [CalculateEffectiveCmEnrollment][].

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the Compliance Manager enrollment to calculate.

Supported formats are the following:

  • organizations/{organization_id}/locations/{location}/cmEnrollment
  • folders/{folder_id}/locations/{location}/cmEnrollment
  • projects/{project_id}/locations/{location}/cmEnrollment.

Returns:

  • (::String)

    Required. The name of the Compliance Manager enrollment to calculate.

    Supported formats are the following:

    • organizations/{organization_id}/locations/{location}/cmEnrollment
    • folders/{folder_id}/locations/{location}/cmEnrollment
    • projects/{project_id}/locations/{location}/cmEnrollment


47
48
49
50
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb', line 47

class CalculateEffectiveCmEnrollmentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end