Class: Google::Cloud::CloudSecurityCompliance::V1::CloudControl

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb

Overview

A cloud control is a set of rules and associated metadata that you can use to define your organization's security or compliance intent.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#categories::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlCategory>

Returns Optional. The categories for the cloud control.

Returns:



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time that the cloud control was last updated. create_time is used because a new cloud control is created whenever an existing cloud control is updated.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The time that the cloud control was last updated. create_time is used because a new cloud control is created whenever an existing cloud control is updated.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#description::String

Returns Optional. A description of the cloud control. The maximum length is 2000 characters.

Returns:

  • (::String)

    Optional. A description of the cloud control. The maximum length is 2000 characters.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#display_name::String

Returns Optional. The friendly name of the cloud control. The maximum length is 200 characters.

Returns:

  • (::String)

    Optional. The friendly name of the cloud control. The maximum length is 200 characters.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#finding_category::String

Returns Optional. The finding category for the cloud control findings. The maximum length is 255 characters.

Returns:

  • (::String)

    Optional. The finding category for the cloud control findings. The maximum length is 255 characters.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#major_revision_id::Integer (readonly)

Returns Output only. The major version of the cloud control, which is incremented in ascending order.

Returns:

  • (::Integer)

    Output only. The major version of the cloud control, which is incremented in ascending order.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#name::String

Returns Required. Identifier. The name of the cloud control, in either of the formats: organizations/{organization}/locations/{location}/cloudControls/{cloud_control} or projects/{project}/locations/{location}/cloudControls/{cloud_control}.

The only supported location is global.

Returns:

  • (::String)

    Required. Identifier. The name of the cloud control, in either of the formats: organizations/{organization}/locations/{location}/cloudControls/{cloud_control} or projects/{project}/locations/{location}/cloudControls/{cloud_control}.

    The only supported location is global.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#parameter_spec::Array<::Google::Cloud::CloudSecurityCompliance::V1::ParameterSpec>

Returns Optional. The parameter specifications for the cloud control.

Returns:



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

Returns Output only. The frameworks that include this cloud control.

Returns:

  • (::Array<::String>)

    Output only. The frameworks that include this cloud control.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#remediation_steps::String

Returns Optional. The remediation steps for the cloud control findings. The maximum length is 400 characters.

Returns:

  • (::String)

    Optional. The remediation steps for the cloud control findings. The maximum length is 400 characters.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#rules::Array<::Google::Cloud::CloudSecurityCompliance::V1::Rule>

Returns Optional. The rules that you can enforce to meet your security or compliance intent.

Returns:



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#severity::Google::Cloud::CloudSecurityCompliance::V1::Severity

Returns Optional. The severity of the findings that are generated by the cloud control.

Returns:



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#supported_cloud_providers::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudProvider>

Returns Optional. The supported cloud providers.

Returns:



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#supported_enforcement_modes::Array<::Google::Cloud::CloudSecurityCompliance::V1::EnforcementMode> (readonly)

Returns Output only. The supported enforcement modes for the cloud control.

Returns:



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end

#supported_target_resource_types::Array<::Google::Cloud::CloudSecurityCompliance::V1::TargetResourceType>

Returns Optional. The target resource types that are supported by the cloud control.

Returns:



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 202

class CloudControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of cloud control.
  module Type
    # Default value. This value is unused.
    TYPE_UNSPECIFIED = 0

    # A cloud control that's created and managed by you.
    CUSTOM = 1

    # A cloud control that's provided and managed by Google.
    BUILT_IN = 2
  end
end