Class: Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb

Overview

A cloud control deployment represents the deployment of a particular cloud control on a target resource. Supported target resources are organizations/{organizationID}, folders/{folderID}, and projects/{projectID}.

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_control_metadata::Google::Cloud::CloudSecurityCompliance::V1::CloudControlMetadata

Returns Required. The deployment mode and parameters for the cloud control.

Returns:



157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the resource was created.

Returns:



157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deployment_state::Google::Cloud::CloudSecurityCompliance::V1::DeploymentState (readonly)

Returns Output only. The state of the cloud control deployment.

Returns:



157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String

Returns Optional. A friendly description for the cloud control deployment.

Returns:

  • (::String)

    Optional. A friendly description for the cloud control deployment.



157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#etag::String

Returns Optional. To prevent concurrent updates from overwriting each other, provide the etag when you update a cloud control deployment. You can also provide the etag when you delete a cloud control deployment to help ensure that you're deleting the intended version of the deployment.

Returns:

  • (::String)

    Optional. To prevent concurrent updates from overwriting each other, provide the etag when you update a cloud control deployment. You can also provide the etag when you delete a cloud control deployment to help ensure that you're deleting the intended version of the deployment.



157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#framework_deployment_references::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeploymentReference> (readonly)

Returns Output only. The references to the framework deployments that this cloud control deployment is part of. A cloud control deployment can be part of multiple framework deployments.

Returns:



157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The name for the cloud control deployment, in the format organizations/{organization}/locations/{location}/cloudControlDeployments/{cloud_control_deployment} or projects/{project}/locations/{location}/cloudControlDeployments/{cloud_control_deployment}. The only supported location is global.

Returns:

  • (::String)

    Identifier. The name for the cloud control deployment, in the format organizations/{organization}/locations/{location}/cloudControlDeployments/{cloud_control_deployment} or projects/{project}/locations/{location}/cloudControlDeployments/{cloud_control_deployment}. The only supported location is global.



157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parameter_substituted_cloud_control::Google::Cloud::CloudSecurityCompliance::V1::CloudControl (readonly)

Returns Output only. The cloud control after the given parameters are substituted.

Returns:



157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_resource::String (readonly)

Returns Output only. The resource that the cloud control is deployed on, in one of the following formats:

  • organizations/{organizationID}
  • folders/{folderID}
  • projects/{projectID}.

Returns:

  • (::String)

    Output only. The resource that the cloud control is deployed on, in one of the following formats:

    • organizations/{organizationID}
    • folders/{folderID}
    • projects/{projectID}


157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_resource_config::Google::Cloud::CloudSecurityCompliance::V1::TargetResourceConfig

Returns Required. The details of the target resource that the cloud control is deployed You can use an existing target resource or create a new target.

Returns:



157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_resource_display_name::String (readonly)

Returns Output only. The display name of the target resource.

Returns:

  • (::String)

    Output only. The display name of the target resource.



157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the resource was last updated.

Returns:



157
158
159
160
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 157

class CloudControlDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end