Class: Google::Cloud::CloudSecurityCompliance::V1::CloudControlDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb

Overview

The details of a cloud control.

Instance Attribute Summary collapse

Instance Attribute Details

#major_revision_id::Integer

Returns Required. The major version of the cloud control.

Returns:

  • (::Integer)

    Required. The major version of the cloud control.



102
103
104
105
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 102

class CloudControlDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the cloud control, in one of the following formats: organizations/{organization}/locations/{location}/cloudControls/{cloud_control} or projects/{project}/locations/{location}/cloudControls/{cloud_control}.

The only supported location is global.

Returns:

  • (::String)

    Required. The name of the cloud control, in one of the following formats: organizations/{organization}/locations/{location}/cloudControls/{cloud_control} or projects/{project}/locations/{location}/cloudControls/{cloud_control}.

    The only supported location is global.



102
103
104
105
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 102

class CloudControlDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parameters::Array<::Google::Cloud::CloudSecurityCompliance::V1::Parameter>

Returns Optional. Parameters are key-value pairs that let you provide your custom location requirements, environment requirements, or other settings that are relevant to the cloud control. An example parameter is {"name": "location","value": "us-west-1"}.

Returns:

  • (::Array<::Google::Cloud::CloudSecurityCompliance::V1::Parameter>)

    Optional. Parameters are key-value pairs that let you provide your custom location requirements, environment requirements, or other settings that are relevant to the cloud control. An example parameter is {"name": "location","value": "us-west-1"}.



102
103
104
105
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 102

class CloudControlDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end