Class: Google::Cloud::CloudSecurityCompliance::V1::CmEnrollmentService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::CmEnrollmentService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/cloud_security_compliance/v1/cm_enrollment_service/rest/client.rb
Overview
REST client for the CmEnrollmentService service.
Service describing CmEnrollment related RPCs for complianceManager.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the CmEnrollmentService Client class.
Instance Method Summary collapse
-
#calculate_effective_cm_enrollment(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CalculateEffectiveCmEnrollmentResponse
Calculates the effective Compliance Manager enrollment for a resource.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the CmEnrollmentService Client instance.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new CmEnrollmentService REST client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_cm_enrollment(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CmEnrollment
Updates the Compliance Manager enrollment for a resource to facilitate an audit.
Methods included from Paths
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new CmEnrollmentService REST client object.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/google/cloud/cloud_security_compliance/v1/cm_enrollment_service/rest/client.rb', line 138 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @cm_enrollment_service_stub = ::Google::Cloud::CloudSecurityCompliance::V1::CmEnrollmentService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @cm_enrollment_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @cm_enrollment_service_stub.endpoint config.universe_domain = @cm_enrollment_service_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @cm_enrollment_service_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
194 195 196 |
# File 'lib/google/cloud/cloud_security_compliance/v1/cm_enrollment_service/rest/client.rb', line 194 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the CmEnrollmentService Client class.
See Configuration for a description of the configuration fields.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/google/cloud/cloud_security_compliance/v1/cm_enrollment_service/rest/client.rb', line 66 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "CloudSecurityCompliance", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.update_cm_enrollment.timeout = 60.0 default_config.rpcs.update_cm_enrollment.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.calculate_effective_cm_enrollment.timeout = 60.0 default_config.rpcs.calculate_effective_cm_enrollment.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#calculate_effective_cm_enrollment(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CalculateEffectiveCmEnrollmentResponse #calculate_effective_cm_enrollment(name: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CalculateEffectiveCmEnrollmentResponse
Calculates the effective Compliance Manager enrollment for a resource. An effective enrollment is either a direct enrollment of a resource (if it exists), or an enrollment of the closest parent of a resource that's enrolled in Compliance Manager.
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/google/cloud/cloud_security_compliance/v1/cm_enrollment_service/rest/client.rb', line 343 def calculate_effective_cm_enrollment request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::CalculateEffectiveCmEnrollmentRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.calculate_effective_cm_enrollment..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.calculate_effective_cm_enrollment.timeout, metadata: , retry_policy: @config.rpcs.calculate_effective_cm_enrollment.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @cm_enrollment_service_stub.calculate_effective_cm_enrollment request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the CmEnrollmentService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
108 109 110 111 |
# File 'lib/google/cloud/cloud_security_compliance/v1/cm_enrollment_service/rest/client.rb', line 108 def configure yield @config if block_given? @config end |
#logger ⇒ Logger
The logger used for request/response debug logging.
201 202 203 |
# File 'lib/google/cloud/cloud_security_compliance/v1/cm_enrollment_service/rest/client.rb', line 201 def logger @cm_enrollment_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
118 119 120 |
# File 'lib/google/cloud/cloud_security_compliance/v1/cm_enrollment_service/rest/client.rb', line 118 def universe_domain @cm_enrollment_service_stub.universe_domain end |
#update_cm_enrollment(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CmEnrollment #update_cm_enrollment(cm_enrollment: nil, update_mask: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CmEnrollment
Updates the Compliance Manager enrollment for a resource to facilitate an audit. Use this method to enroll a resource in Compliance Manager or to create or update feature-specific configurations.
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/google/cloud/cloud_security_compliance/v1/cm_enrollment_service/rest/client.rb', line 256 def update_cm_enrollment request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::UpdateCmEnrollmentRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_cm_enrollment..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_cm_enrollment.timeout, metadata: , retry_policy: @config.rpcs.update_cm_enrollment.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @cm_enrollment_service_stub.update_cm_enrollment request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |