Class: Google::Cloud::CloudSecurityCompliance::V1::Config::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/cloud_security_compliance/v1/config/client.rb

Overview

Client for the Config service.

Config Service manages compliance frameworks, cloud controls, and their configurations.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#cloud_control_path, #framework_path, #location_path, #organization_location_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new Config client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Config client.

Yield Parameters:



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 158

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/cloudsecuritycompliance/v1/config_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @config_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::CloudSecurityCompliance::V1::Config::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @config_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config_stub.endpoint
    config.universe_domain = @config_stub.universe_domain
    config.logger = @config_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Client)


222
223
224
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 222

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the Config Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all Config clients
::Google::Cloud::CloudSecurityCompliance::V1::Config::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 64

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "CloudSecurityCompliance", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.list_frameworks.timeout = 60.0
    default_config.rpcs.list_frameworks.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_framework.timeout = 60.0
    default_config.rpcs.get_framework.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.create_framework.timeout = 60.0

    default_config.rpcs.update_framework.timeout = 60.0

    default_config.rpcs.delete_framework.timeout = 60.0

    default_config.rpcs.list_cloud_controls.timeout = 60.0
    default_config.rpcs.list_cloud_controls.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_cloud_control.timeout = 60.0
    default_config.rpcs.get_cloud_control.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.create_cloud_control.timeout = 60.0

    default_config.rpcs.update_cloud_control.timeout = 60.0

    default_config.rpcs.delete_cloud_control.timeout = 60.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the Config Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



128
129
130
131
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 128

def configure
  yield @config if block_given?
  @config
end

#create_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl #create_cloud_control(parent: nil, cloud_control_id: nil, cloud_control: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl

Creates a custom cloud control in a given parent resource. You can't create built-in cloud controls because those are managed by Google.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::CreateCloudControlRequest.new

# Call the create_cloud_control method.
result = client.create_cloud_control request

# The returned object is of type Google::Cloud::CloudSecurityCompliance::V1::CloudControl.
p result

Overloads:

  • #create_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl

    Pass arguments to create_cloud_control via a request object, either of type Google::Cloud::CloudSecurityCompliance::V1::CreateCloudControlRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::CreateCloudControlRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_cloud_control(parent: nil, cloud_control_id: nil, cloud_control: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl

    Pass arguments to create_cloud_control via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource name, in one of the following formats:

      • organizations/{organization}/locations/{location}.
      • projects/{project}/locations/{location}.

      The only supported location is global.

    • cloud_control_id (::String) (defaults to: nil)

      Required. The identifier for the cloud control, which is the last segment of the cloud control name. The format is ^[a-zA-Z][a-zA-Z0-9-]{0,61}[a-zA-Z0-9]$.

    • cloud_control (::Google::Cloud::CloudSecurityCompliance::V1::CloudControl, ::Hash) (defaults to: nil)

      Required. The cloud control that's being created.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 1005

def create_cloud_control request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::CreateCloudControlRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_cloud_control..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_cloud_control.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_cloud_control.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @config_stub.call_rpc :create_cloud_control, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#create_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework #create_framework(parent: nil, framework_id: nil, framework: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework

Creates a custom framework in a given parent resource. You can't create built-in frameworks because those are managed by Google.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkRequest.new

# Call the create_framework method.
result = client.create_framework request

# The returned object is of type Google::Cloud::CloudSecurityCompliance::V1::Framework.
p result

Overloads:

  • #create_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework

    Pass arguments to create_framework via a request object, either of type Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_framework(parent: nil, framework_id: nil, framework: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework

    Pass arguments to create_framework via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource name, in one of the following formats:

      • organizations/{organization}/locations/{location}
      • projects/{project}/locations/{location}.

      The only supported location is global.

    • framework_id (::String) (defaults to: nil)

      Required. The identifier (ID) of the framework. The ID is not the full name of the framework; it's the last part of the full name of the framework.

    • framework (::Google::Cloud::CloudSecurityCompliance::V1::Framework, ::Hash) (defaults to: nil)

      Required. The resource being created.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 495

def create_framework request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_framework..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_framework.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_framework.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @config_stub.call_rpc :create_framework, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_cloud_control(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_cloud_control(name: nil) ⇒ ::Google::Protobuf::Empty

Deletes a custom cloud control, including all its major and minor revisions. Consider the following:

  • You can't delete built-in cloud controls. You can only delete cloud controls with type CUSTOM.
  • You can't delete cloud controls if any of the versions are referenced by a framework.
  • You can't restore a deleted cloud control. This action is permanent.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::DeleteCloudControlRequest.new

# Call the delete_cloud_control method.
result = client.delete_cloud_control request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_cloud_control(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_cloud_control via a request object, either of type DeleteCloudControlRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::DeleteCloudControlRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_cloud_control(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_cloud_control via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the cloud control to delete, in one of the following formats: organizations/{organization}/locations/{location}/CloudControls/{CloudControl} or projects/{project}/locations/{location}/CloudControls/{CloudControl}.

      The only supported location is global.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 1214

def delete_cloud_control request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::DeleteCloudControlRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_cloud_control..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_cloud_control.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_cloud_control.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @config_stub.call_rpc :delete_cloud_control, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_framework(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_framework(name: nil) ⇒ ::Google::Protobuf::Empty

Deletes a custom framework, including all its major and minor revisions. Consider the following:

  • You can't delete built-in frameworks. You can only delete frameworks with type CUSTOM.
  • You can't delete frameworks that are deployed to a resource.
  • You can't restore a deleted framework. This action is permanent.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::DeleteFrameworkRequest.new

# Call the delete_framework method.
result = client.delete_framework request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_framework(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_framework via a request object, either of type DeleteFrameworkRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::DeleteFrameworkRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_framework(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_framework via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the resource, in one of the following formats: organizations/{organization}/locations/{location}/frameworks/{framework} or projects/{project}/locations/{location}/frameworks/{framework}.

      The only supported location is global.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 695

def delete_framework request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::DeleteFrameworkRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_framework..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_framework.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_framework.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @config_stub.call_rpc :delete_framework, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl #get_cloud_control(name: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl

Gets details about a cloud control. This method retrieves the latest major version of a cloud control that you identify by name.

By default, the latest major version of the cloud control is returned. To retrieve a specific major version, include major_revision_id in the request.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::GetCloudControlRequest.new

# Call the get_cloud_control method.
result = client.get_cloud_control request

# The returned object is of type Google::Cloud::CloudSecurityCompliance::V1::CloudControl.
p result

Overloads:

  • #get_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl

    Pass arguments to get_cloud_control via a request object, either of type GetCloudControlRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::GetCloudControlRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_cloud_control(name: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl

    Pass arguments to get_cloud_control via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the cloud control to retrieve, in one of the following formats: organizations/{organization}/locations/{location}/cloudControls/{cloud_control} or projects/{project}/locations/{location}/cloudControls/{cloud_control}.

      The only supported location is global.

    • major_revision_id (::Integer) (defaults to: nil)

      Optional. The major version of the cloud control to retrieve. If not specified, the most recently updated revision_id is retrieved.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 907

def get_cloud_control request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::GetCloudControlRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_cloud_control..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_cloud_control.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_cloud_control.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @config_stub.call_rpc :get_cloud_control, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework #get_framework(name: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework

Gets details about a framework. This method retrieves the latest major version of the framework.

To retrieve a specific major version, include major_revision_id in the request.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::GetFrameworkRequest.new

# Call the get_framework method.
result = client.get_framework request

# The returned object is of type Google::Cloud::CloudSecurityCompliance::V1::Framework.
p result

Overloads:

  • #get_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework

    Pass arguments to get_framework via a request object, either of type GetFrameworkRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::GetFrameworkRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_framework(name: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework

    Pass arguments to get_framework via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the framework to retrieve, in one of the following formats: organizations/{organization}/locations/{location}/frameworks/{framework} or projects/{project}/locations/{location}/frameworks/{framework}.

      The only supported location is global.

    • major_revision_id (::Integer) (defaults to: nil)

      Optional. The framework major version to retrieve. If not specified, the most recently updated revision_id is retrieved.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 399

def get_framework request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::GetFrameworkRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_framework..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_framework.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_framework.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @config_stub.call_rpc :get_framework, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_cloud_controls(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControl> #list_cloud_controls(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControl>

Lists the cloud controls (both built-in and custom) that are available in a given parent resource. The latest major version of each cloud control is returned. This method supports pagination.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlsRequest.new

# Call the list_cloud_controls method.
result = client.list_cloud_controls request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl.
  p item
end

Overloads:

  • #list_cloud_controls(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControl>

    Pass arguments to list_cloud_controls via a request object, either of type ListCloudControlsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_cloud_controls(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControl>

    Pass arguments to list_cloud_controls via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource name, in one of the following formats:

      • organizations/{organization}/locations/{location}
      • projects/{project}/locations/{location}.

      The only supported location is global.

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of cloud controls to return. The default value is 500.

      If you exceed the maximum value of 1000, then the service uses the maximum value.

    • page_token (::String) (defaults to: nil)

      Optional. A pagination token that's returned from a previous request to list cloud controls. Provide this token to retrieve the next page of results.

      When paginating, the parent that you provide to the ListCloudControls request must match the call that provided the page token.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 805

def list_cloud_controls request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_cloud_controls..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_cloud_controls.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_cloud_controls.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @config_stub.call_rpc :list_cloud_controls, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @config_stub, :list_cloud_controls, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_frameworks(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::Framework> #list_frameworks(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::Framework>

Lists the frameworks (both built-in and custom) that are available within the parent resource. The latest major version of each framework is returned. This method supports pagination.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::ListFrameworksRequest.new

# Call the list_frameworks method.
result = client.list_frameworks request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudSecurityCompliance::V1::Framework.
  p item
end

Overloads:

  • #list_frameworks(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::Framework>

    Pass arguments to list_frameworks via a request object, either of type ListFrameworksRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::ListFrameworksRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_frameworks(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::Framework>

    Pass arguments to list_frameworks via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource name, in one of the following formats:

      • organizations/{organization}/locations/{location}
      • projects/{project}/locations/{location}.

      The only supported location is global.

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of frameworks to return. The default value is 500.

      If you exceed the maximum value of 1000, then the service uses the maximum value.

    • page_token (::String) (defaults to: nil)

      Optional. A pagination token returned from a previous request to list frameworks. Provide this token to retrieve the next page of results.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 299

def list_frameworks request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListFrameworksRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_frameworks..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_frameworks.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_frameworks.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @config_stub.call_rpc :list_frameworks, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @config_stub, :list_frameworks, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


229
230
231
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 229

def logger
  @config_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


138
139
140
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 138

def universe_domain
  @config_stub.universe_domain
end

#update_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl #update_cloud_control(update_mask: nil, cloud_control: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl

Updates a custom cloud control. This method allows for partial updates of a cloud control. Use the update_mask to specify which fields to update. Consider the following:

  • If you provide an update_mask, only the fields that are specified in the mask are updated.
  • If you don't provide an update_mask, all the fields that are present in the request's cloud_control body are used to overwrite the existing resource.

You can only update cloud controls with the CUSTOM type. A successful update creates a new version of the cloud control.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::UpdateCloudControlRequest.new

# Call the update_cloud_control method.
result = client.update_cloud_control request

# The returned object is of type Google::Cloud::CloudSecurityCompliance::V1::CloudControl.
p result

Overloads:

  • #update_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl

    Pass arguments to update_cloud_control via a request object, either of type UpdateCloudControlRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::UpdateCloudControlRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_cloud_control(update_mask: nil, cloud_control: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl

    Pass arguments to update_cloud_control via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Optional. Use a field mask to specify the fields to be overwritten in the cloud control during the update. The fields that you specify in the update_mask are relative to the cloud control, not the full request. A field is overwritten if it is in the mask. If you don't provide a mask, all fields in the request are updated.

      You can update the following fields:

      • Display name
      • Description
      • Parameters
      • Rules
      • Parameter specification
    • cloud_control (::Google::Cloud::CloudSecurityCompliance::V1::CloudControl, ::Hash) (defaults to: nil)

      Required. The cloud control that you're updating.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 1116

def update_cloud_control request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::UpdateCloudControlRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_cloud_control..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.cloud_control&.name
    header_params["cloud_control.name"] = request.cloud_control.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_cloud_control.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_cloud_control.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @config_stub.call_rpc :update_cloud_control, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework #update_framework(update_mask: nil, framework: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework

Updates a custom framework. This method allows for partial updates of a framework. Use the update_mask to specify which fields to update. Consider the following:

  • If you provide an update_mask, only the fields that are specified in the mask are updated.
  • If you don't provide an update_mask, all the fields that are present in the request's framework body are used to overwrite the existing resource.

You can only update frameworks with the CUSTOM type. A successful update creates a new version of the framework.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Config::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::UpdateFrameworkRequest.new

# Call the update_framework method.
result = client.update_framework request

# The returned object is of type Google::Cloud::CloudSecurityCompliance::V1::Framework.
p result

Overloads:

  • #update_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework

    Pass arguments to update_framework via a request object, either of type UpdateFrameworkRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::UpdateFrameworkRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_framework(update_mask: nil, framework: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework

    Pass arguments to update_framework via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Optional. A field mask is used to specify the fields to be overwritten in the framework resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field is overwritten if it is in the mask. If you don't provide a mask then all fields present in the request will be overwritten.

    • framework (::Google::Cloud::CloudSecurityCompliance::V1::Framework, ::Hash) (defaults to: nil)

      Required. The resource that is being updated.

    • major_revision_id (::Integer) (defaults to: nil)

      Optional. The major version ID of the framework to update.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 599

def update_framework request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::UpdateFrameworkRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_framework..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.framework&.name
    header_params["framework.name"] = request.framework.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_framework.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_framework.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @config_stub.call_rpc :update_framework, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end