Class: Google::Cloud::CloudSecurityCompliance::V1::Control

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb

Overview

The regulatory control.

Defined Under Namespace

Modules: Family

Instance Attribute Summary collapse

Instance Attribute Details

#additional_content_uri::String (readonly)

Returns Output only. A link to the documentation that's related to this control.

Returns:

  • (::String)

    Output only. A link to the documentation that's related to this control.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

#control_family::Google::Cloud::CloudSecurityCompliance::V1::ControlFamily (readonly)

Returns Output only. The regulatory family that the control belongs to.

Returns:



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

#customer_responsibility_description::String (readonly)

Returns Output only. A description of your responsibility for the regulatory control.

Returns:

  • (::String)

    Output only. A description of your responsibility for the regulatory control.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

#customer_responsibility_implementation::String (readonly)

Returns Output only. A description of the your responsibility for implementing the regulatory control.

Returns:

  • (::String)

    Output only. A description of the your responsibility for implementing the regulatory control.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

#description::String (readonly)

Returns Output only. The description of the regulatory control.

Returns:

  • (::String)

    Output only. The description of the regulatory control.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

#display_name::String (readonly)

Returns Output only. The friendly name for the regulatory control.

Returns:

  • (::String)

    Output only. The friendly name for the regulatory control.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

#family::Google::Cloud::CloudSecurityCompliance::V1::Control::Family (readonly)

Returns Output only. The regulatory group that the control belongs to.

Returns:



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

#google_responsibility_description::String (readonly)

Returns Output only. A description of Google's responsibility for the regulatory control.

Returns:

  • (::String)

    Output only. A description of Google's responsibility for the regulatory control.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

#google_responsibility_implementation::String (readonly)

Returns Output only. A description of Google's responsibility for implementing the regulatory control.

Returns:

  • (::String)

    Output only. A description of Google's responsibility for implementing the regulatory control.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

#name::String (readonly)

Returns Output only. The name of a regulatory control, in one of the following formats:

  • organizations/{organization}/locations/{location}/controls/{control}
  • projects/{project}/locations/{location}/controls/{control}.

The only supported location is global.

Returns:

  • (::String)

    Output only. The name of a regulatory control, in one of the following formats:

    • organizations/{organization}/locations/{location}/controls/{control}
    • projects/{project}/locations/{location}/controls/{control}.

    The only supported location is global.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

Returns Output only. The frameworks that include this control.

Returns:

  • (::Array<::String>)

    Output only. The frameworks that include this control.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

#responsibility_type::Google::Cloud::CloudSecurityCompliance::V1::RegulatoryControlResponsibilityType (readonly)

Returns Output only. The entity that's responsible for the control, whether Google, you as the customer, or both.

Returns:



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end

#shared_responsibility_description::String (readonly)

Returns Output only. A description of the responsibility that's shared between Google and you in implementing this control.

Returns:

  • (::String)

    Output only. A description of the responsibility that's shared between Google and you in implementing this control.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 516

class Control
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The regulatory control family.
  module Family
    # Default value. This value is unused.
    FAMILY_UNSPECIFIED = 0

    # Access control
    AC = 1

    # Awareness and araining
    AT = 2

    # Audit and accountability
    AU = 3

    # Certification, accreditation, and security assessments
    CA = 4

    # Configuration management
    CM = 5

    # Contingency planning
    CP = 6

    # Identification and authentication
    IA = 7

    # Incident response
    IR = 8

    # Maintenance
    MA = 9

    # Media protection
    MP = 10

    # Physical and environmental protection
    PE = 11

    # Security planning
    PL = 12

    # Personnel aecurity
    PS = 13

    # Risk assessment
    RA = 14

    # System services and acquisition
    SA = 15

    # System and communications protection
    SC = 16

    # System and information integrity
    SI = 17

    # Supply chain risk management
    SR = 18
  end
end