Class: Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkDeploymentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb

Overview

The request message for [CreateFrameworkDeployment][].

Instance Attribute Summary collapse

Instance Attribute Details

#framework_deployment::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment

Returns Required. The framework deployment that you're creating.

Returns:



260
261
262
263
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 260

class CreateFrameworkDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#framework_deployment_id::String

Returns Optional. An identifier for the framework deployment that's unique in scope of the parent. If you don't specify a value, then a random UUID is generated.

Returns:

  • (::String)

    Optional. An identifier for the framework deployment that's unique in scope of the parent. If you don't specify a value, then a random UUID is generated.



260
261
262
263
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 260

class CreateFrameworkDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource of the framework deployment in the format organizations/{organization}/locations/{location} or projects/{project}/locations/{location}. Only the global location is supported.

Returns:

  • (::String)

    Required. The parent resource of the framework deployment in the format organizations/{organization}/locations/{location} or projects/{project}/locations/{location}. Only the global location is supported.



260
261
262
263
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 260

class CreateFrameworkDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end