Class: Google::Cloud::CloudSecurityCompliance::V1::DeleteCloudControlRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb

Overview

The request message for [DeleteCloudControl][].

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the cloud control to delete, in one of the following formats: organizations/{organization}/locations/{location}/CloudControls/{CloudControl} or projects/{project}/locations/{location}/CloudControls/{CloudControl}.

The only supported location is global.

Returns:

  • (::String)

    Required. The name of the cloud control to delete, in one of the following formats: organizations/{organization}/locations/{location}/CloudControls/{CloudControl} or projects/{project}/locations/{location}/CloudControls/{CloudControl}.

    The only supported location is global.



251
252
253
254
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 251

class DeleteCloudControlRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end