Class: Google::Cloud::CloudSecurityCompliance::V1::DeleteFrameworkDeploymentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb

Overview

The request message for [DeleteFrameworkDeployment][].

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. An opaque identifier for the current version of the resource.

If you provide this value, then it must match the existing value. If the values don't match, then the request fails with an [ABORTED][google.rpc.Code.ABORTED] error.

If you omit this value, then the resource is deleted regardless of its current etag value.

Returns:

  • (::String)

    Optional. An opaque identifier for the current version of the resource.

    If you provide this value, then it must match the existing value. If the values don't match, then the request fails with an [ABORTED][google.rpc.Code.ABORTED] error.

    If you omit this value, then the resource is deleted regardless of its current etag value.



284
285
286
287
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 284

class DeleteFrameworkDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the framework deployment that you want to delete, in the format organizations/{organization}/locations/{location}/frameworkDeployments/{framework_deployment} or projects/{project}/locations/{location}/frameworkDeployments/{framework_deployment}. The only supported location is global.

Returns:

  • (::String)

    Required. The name of the framework deployment that you want to delete, in the format organizations/{organization}/locations/{location}/frameworkDeployments/{framework_deployment} or projects/{project}/locations/{location}/frameworkDeployments/{framework_deployment}. The only supported location is global.



284
285
286
287
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 284

class DeleteFrameworkDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end