Class: Google::Cloud::CloudSecurityCompliance::V1::DeleteFrameworkRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb

Overview

Request message for [DeleteFramework][].

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the resource, in one of the following formats: organizations/{organization}/locations/{location}/frameworks/{framework} or projects/{project}/locations/{location}/frameworks/{framework}.

The only supported location is global.

Returns:

  • (::String)

    Required. The name of the resource, in one of the following formats: organizations/{organization}/locations/{location}/frameworks/{framework} or projects/{project}/locations/{location}/frameworks/{framework}.

    The only supported location is global.



129
130
131
132
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 129

class DeleteFrameworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end