Class: Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb

Overview

REST client for the Deployment service.

Deployment service allows users to manage deployments of Frameworks and Cloud Controls on a target resource.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#cloud_control_deployment_path, #framework_deployment_path, #framework_path, #location_path, #organization_location_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new Deployment REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Deployment client.

Yield Parameters:



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 152

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @operations_client = ::Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Operations.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.universe_domain = @config.universe_domain
  end

  @deployment_stub = ::Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @deployment_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @deployment_stub.endpoint
    config.universe_domain = @deployment_stub.universe_domain
    config.bindings_override = @config.bindings_override
    config.logger = @deployment_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Rest::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Rest::Client)


222
223
224
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 222

def location_client
  @location_client
end

#operations_client::Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Operations (readonly)

Get the associated client for long-running operations.



215
216
217
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 215

def operations_client
  @operations_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the Deployment Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all Deployment clients
::Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 66

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "CloudSecurityCompliance", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_framework_deployment.timeout = 60.0

    default_config.rpcs.delete_framework_deployment.timeout = 60.0

    default_config.rpcs.get_framework_deployment.timeout = 60.0
    default_config.rpcs.get_framework_deployment.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_framework_deployments.timeout = 60.0
    default_config.rpcs.list_framework_deployments.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_cloud_control_deployment.timeout = 60.0
    default_config.rpcs.get_cloud_control_deployment.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_cloud_control_deployments.timeout = 60.0
    default_config.rpcs.list_cloud_control_deployments.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the Deployment Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



122
123
124
125
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 122

def configure
  yield @config if block_given?
  @config
end

#create_framework_deployment(request, options = nil) ⇒ ::Gapic::Operation #create_framework_deployment(parent: nil, framework_deployment_id: nil, framework_deployment: nil) ⇒ ::Gapic::Operation

Creates a framework deployment in a given parent resource. A framework deployment lets you assign a particular framework version to an organization, folder, or project so that you can control and monitor those resources using the framework's cloud controls.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkDeploymentRequest.new

# Call the create_framework_deployment method.
result = client.create_framework_deployment request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #create_framework_deployment(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to create_framework_deployment via a request object, either of type CreateFrameworkDeploymentRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkDeploymentRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_framework_deployment(parent: nil, framework_deployment_id: nil, framework_deployment: nil) ⇒ ::Gapic::Operation

    Pass arguments to create_framework_deployment via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource of the framework deployment in the format organizations/{organization}/locations/{location} or projects/{project}/locations/{location}. Only the global location is supported.

    • framework_deployment_id (::String) (defaults to: nil)

      Optional. An identifier for the framework deployment that's unique in scope of the parent. If you don't specify a value, then a random UUID is generated.

    • framework_deployment (::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment, ::Hash) (defaults to: nil)

      Required. The framework deployment that you're creating.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 298

def create_framework_deployment request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkDeploymentRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_framework_deployment..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_framework_deployment.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_framework_deployment.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @deployment_stub.create_framework_deployment request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_framework_deployment(request, options = nil) ⇒ ::Gapic::Operation #delete_framework_deployment(name: nil, etag: nil) ⇒ ::Gapic::Operation

Deletes a framework deployment.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::DeleteFrameworkDeploymentRequest.new

# Call the delete_framework_deployment method.
result = client.delete_framework_deployment request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #delete_framework_deployment(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to delete_framework_deployment via a request object, either of type Google::Cloud::CloudSecurityCompliance::V1::DeleteFrameworkDeploymentRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::DeleteFrameworkDeploymentRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_framework_deployment(name: nil, etag: nil) ⇒ ::Gapic::Operation

    Pass arguments to delete_framework_deployment via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the framework deployment that you want to delete, in the format organizations/{organization}/locations/{location}/frameworkDeployments/{framework_deployment} or projects/{project}/locations/{location}/frameworkDeployments/{framework_deployment}. The only supported location is global.

    • etag (::String) (defaults to: nil)

      Optional. An opaque identifier for the current version of the resource.

      If you provide this value, then it must match the existing value. If the values don't match, then the request fails with an [ABORTED][google.rpc.Code.ABORTED] error.

      If you omit this value, then the resource is deleted regardless of its current etag value.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 399

def delete_framework_deployment request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::DeleteFrameworkDeploymentRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_framework_deployment..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_framework_deployment.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_framework_deployment.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @deployment_stub.delete_framework_deployment request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_cloud_control_deployment(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment #get_cloud_control_deployment(name: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment

Gets details about a cloud control deployment.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::GetCloudControlDeploymentRequest.new

# Call the get_cloud_control_deployment method.
result = client.get_cloud_control_deployment request

# The returned object is of type Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment.
p result

Overloads:

  • #get_cloud_control_deployment(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment

    Pass arguments to get_cloud_control_deployment via a request object, either of type GetCloudControlDeploymentRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::GetCloudControlDeploymentRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_cloud_control_deployment(name: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment

    Pass arguments to get_cloud_control_deployment via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name for the cloud control deployment, in the format organizations/{organization}/locations/{location}/cloudControlDeployments/{cloud_control_deployment} or projects/{project}/locations/{location}/cloudControlDeployments/{cloud_control_deployment}. The only supported location is global.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 671

def get_cloud_control_deployment request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::GetCloudControlDeploymentRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_cloud_control_deployment..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_cloud_control_deployment.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_cloud_control_deployment.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @deployment_stub.get_cloud_control_deployment request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_framework_deployment(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment #get_framework_deployment(name: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment

Gets details about a framework deployment.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::GetFrameworkDeploymentRequest.new

# Call the get_framework_deployment method.
result = client.get_framework_deployment request

# The returned object is of type Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment.
p result

Overloads:

  • #get_framework_deployment(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment

    Pass arguments to get_framework_deployment via a request object, either of type GetFrameworkDeploymentRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::GetFrameworkDeploymentRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_framework_deployment(name: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment

    Pass arguments to get_framework_deployment via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the framework deployment, in the format organizations/{organization}/locations/{location}/frameworkDeployments/{framework_deployment} or projects/{project}/locations/{location}/frameworkDeployments/{framework_deployment}. The only supported location is global.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 483

def get_framework_deployment request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::GetFrameworkDeploymentRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_framework_deployment..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_framework_deployment.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_framework_deployment.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @deployment_stub.get_framework_deployment request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_cloud_control_deployments(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment> #list_cloud_control_deployments(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment>

Lists the cloud conrol deployments in a given parent resource.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlDeploymentsRequest.new

# Call the list_cloud_control_deployments method.
result = client.list_cloud_control_deployments request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment.
  p item
end

Overloads:

  • #list_cloud_control_deployments(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment>

    Pass arguments to list_cloud_control_deployments via a request object, either of type ListCloudControlDeploymentsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlDeploymentsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_cloud_control_deployments(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment>

    Pass arguments to list_cloud_control_deployments via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource for the cloud control deployment, in the format organizations/{organization}/locations/{location} or projects/{project}/locations/{location}. The only supported location is global.

    • page_size (::Integer) (defaults to: nil)

      Optional. The requested page size. The server might return fewer items than you requested. If unspecified, the server picks an appropriate default.

    • page_token (::String) (defaults to: nil)

      Optional. A token that identifies the page of results that the server should return.

    • filter (::String) (defaults to: nil)

      Optional. The filter to apply on the resource, as defined by AIP-160: Filtering.

    • order_by (::String) (defaults to: nil)

      Optional. The sort order for the results. The following values are supported:

      • name
      • name desc

      If you do not specify a value, then the results are not sorted.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 774

def list_cloud_control_deployments request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlDeploymentsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_cloud_control_deployments..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_cloud_control_deployments.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_cloud_control_deployments.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @deployment_stub.list_cloud_control_deployments request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @deployment_stub, :list_cloud_control_deployments, "cloud_control_deployments", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_framework_deployments(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment> #list_framework_deployments(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment>

Lists the framework deployments in a given parent resource.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Deployment::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkDeploymentsRequest.new

# Call the list_framework_deployments method.
result = client.list_framework_deployments request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment.
  p item
end

Overloads:

  • #list_framework_deployments(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment>

    Pass arguments to list_framework_deployments via a request object, either of type ListFrameworkDeploymentsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkDeploymentsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_framework_deployments(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment>

    Pass arguments to list_framework_deployments via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource of the framework deployment, in the format organizations/{organization}/locations/{location} or projects/{project}/locations/{location}. The only supported location is global.

    • page_size (::Integer) (defaults to: nil)

      Optional. The requested page size. The server might return fewer items than requested. If unspecified, the server picks an appropriate default.

    • page_token (::String) (defaults to: nil)

      Optional. A token that identifies a page of results the server should return.

    • filter (::String) (defaults to: nil)

      Optional. The filter to be applied on the resource, as defined by AIP-160: Filtering.

    • order_by (::String) (defaults to: nil)

      Optional. The sort order for the results. The following values are supported:

      • name
      • name desc

      If you do not specify a value, then the results are not sorted.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 587

def list_framework_deployments request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkDeploymentsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_framework_deployments..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_framework_deployments.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_framework_deployments.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @deployment_stub.list_framework_deployments request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @deployment_stub, :list_framework_deployments, "framework_deployments", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


229
230
231
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 229

def logger
  @deployment_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


132
133
134
# File 'lib/google/cloud/cloud_security_compliance/v1/deployment/rest/client.rb', line 132

def universe_domain
  @deployment_stub.universe_domain
end