Class: Google::Cloud::CloudSecurityCompliance::V1::FetchFrameworkComplianceReportRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb

Overview

The request message for [FetchFrameworkComplianceReport][].

Instance Attribute Summary collapse

Instance Attribute Details

#end_time::Google::Protobuf::Timestamp

Returns Optional. The end time of the report.

Returns:



113
114
115
116
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 113

class FetchFrameworkComplianceReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#filter::String

Returns Optional. The filtering results.

Returns:

  • (::String)

    Optional. The filtering results.



113
114
115
116
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 113

class FetchFrameworkComplianceReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the framework compliance report to retrieve.

Returns:

  • (::String)

    Required. The name of the framework compliance report to retrieve.



113
114
115
116
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 113

class FetchFrameworkComplianceReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end