Module: Google::Cloud::CloudSecurityCompliance::V1::FindingClass

Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb

Overview

A finding is a record of assessment data like security, risk, health, or privacy.

Constant Summary collapse

FINDING_CLASS_UNSPECIFIED =

Default value. This value is unused.

0
THREAT =

The activity is unwanted or malicious.

1
VULNERABILITY =

A potential weakness in software that increases risk to confidentiality, integrity, and availability.

2
MISCONFIGURATION =

A potential weakness in a cloud resource or asset configuration that increases risk.

3
OBSERVATION =

A security observation that is for informational purposes.

4
SCC_ERROR =

An error that prevents Security Command Center from functioning properly.

5
POSTURE_VIOLATION =

A potential security risk that's due to a change in the security posture.

6
TOXIC_COMBINATION =

A combination of security issues that represent a more severe security problem when taken together.

7
SENSITIVE_DATA_RISK =

A potential security risk to data assets that contain sensitive data.

8
CHOKEPOINT =

A resource or resource group where high risk attack paths converge, based on attack path simulations (APS).

9