Class: Google::Cloud::CloudSecurityCompliance::V1::FindingSummary

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb

Overview

The details for a finding.

Instance Attribute Summary collapse

Instance Attribute Details

#finding_category::String

Returns The category of the finding.

Returns:

  • (::String)

    The category of the finding.



302
303
304
305
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 302

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#finding_class::Google::Cloud::CloudSecurityCompliance::V1::FindingClass

Returns The class of the finding.

Returns:



302
303
304
305
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 302

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#finding_count::Integer

Returns The count of the finding.

Returns:

  • (::Integer)

    The count of the finding.



302
303
304
305
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 302

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The name of the finding summary.

Returns:

  • (::String)

    Identifier. The name of the finding summary.



302
303
304
305
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 302

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Optional. The list of compliance frameworks that the finding belongs to.

Returns:

  • (::Array<::String>)

    Optional. The list of compliance frameworks that the finding belongs to.



302
303
304
305
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 302

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#severity::Google::Cloud::CloudSecurityCompliance::V1::Severity

Returns The severity of the finding.

Returns:



302
303
304
305
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 302

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The last updated time of the finding.

Returns:



302
303
304
305
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 302

class FindingSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end