Class: Google::Cloud::CloudSecurityCompliance::V1::FolderCreationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb

Overview

The configuration that's required to create a folder to be used as the target resource for a deployment.

Instance Attribute Summary collapse

Instance Attribute Details

#folder_display_name::String

Returns Required. The display name of the folder.

Returns:

  • (::String)

    Required. The display name of the folder.



209
210
211
212
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 209

class FolderCreationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent of the folder, in the format organizations/{organizationID} or folders/{folderID}.

Returns:

  • (::String)

    Required. The parent of the folder, in the format organizations/{organizationID} or folders/{folderID}.



209
210
211
212
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 209

class FolderCreationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end