Class: Google::Cloud::CloudSecurityCompliance::V1::Framework

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb

Overview

A framework is a collection of cloud controls and regulatory controls that represent security best practices or industry-defined standards such as FedRAMP or NIST.

Defined Under Namespace

Modules: FrameworkType

Instance Attribute Summary collapse

Instance Attribute Details

#category::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkCategory>

Returns Optional. The category of the framework.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 67

class Framework
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of framework.
  module FrameworkType
    # Default value. This value is unused.
    FRAMEWORK_TYPE_UNSPECIFIED = 0

    # A framework that's provided and managed by Google.
    BUILT_IN = 1

    # A framework that's created and managed by you.
    CUSTOM = 2
  end
end

#cloud_control_details::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDetails>

Returns Optional. The cloud control details that are directly added without any grouping in the framework.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 67

class Framework
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of framework.
  module FrameworkType
    # Default value. This value is unused.
    FRAMEWORK_TYPE_UNSPECIFIED = 0

    # A framework that's provided and managed by Google.
    BUILT_IN = 1

    # A framework that's created and managed by you.
    CUSTOM = 2
  end
end

#description::String

Returns Optional. The description of the framework. The maximum length is 2000 characters.

Returns:

  • (::String)

    Optional. The description of the framework. The maximum length is 2000 characters.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 67

class Framework
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of framework.
  module FrameworkType
    # Default value. This value is unused.
    FRAMEWORK_TYPE_UNSPECIFIED = 0

    # A framework that's provided and managed by Google.
    BUILT_IN = 1

    # A framework that's created and managed by you.
    CUSTOM = 2
  end
end

#display_name::String

Returns Optional. The friendly name of the framework. The maximum length is 200 characters.

Returns:

  • (::String)

    Optional. The friendly name of the framework. The maximum length is 200 characters.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 67

class Framework
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of framework.
  module FrameworkType
    # Default value. This value is unused.
    FRAMEWORK_TYPE_UNSPECIFIED = 0

    # A framework that's provided and managed by Google.
    BUILT_IN = 1

    # A framework that's created and managed by you.
    CUSTOM = 2
  end
end

#major_revision_id::Integer (readonly)

Returns Output only. The major version of the framework, which is incremented in ascending order.

Returns:

  • (::Integer)

    Output only. The major version of the framework, which is incremented in ascending order.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 67

class Framework
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of framework.
  module FrameworkType
    # Default value. This value is unused.
    FRAMEWORK_TYPE_UNSPECIFIED = 0

    # A framework that's provided and managed by Google.
    BUILT_IN = 1

    # A framework that's created and managed by you.
    CUSTOM = 2
  end
end

#name::String

Returns Required. Identifier. The name of the framework, in one of the following formats: organizations/{organization}/locations/{location}/frameworks/{framework} or projects/{project}/locations/{location}/frameworks/{framework}.

The only supported location is global.

Returns:

  • (::String)

    Required. Identifier. The name of the framework, in one of the following formats: organizations/{organization}/locations/{location}/frameworks/{framework} or projects/{project}/locations/{location}/frameworks/{framework}.

    The only supported location is global.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 67

class Framework
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of framework.
  module FrameworkType
    # Default value. This value is unused.
    FRAMEWORK_TYPE_UNSPECIFIED = 0

    # A framework that's provided and managed by Google.
    BUILT_IN = 1

    # A framework that's created and managed by you.
    CUSTOM = 2
  end
end

#supported_cloud_providers::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudProvider> (readonly)

Returns Output only. The cloud providers that are supported by the framework.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 67

class Framework
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of framework.
  module FrameworkType
    # Default value. This value is unused.
    FRAMEWORK_TYPE_UNSPECIFIED = 0

    # A framework that's provided and managed by Google.
    BUILT_IN = 1

    # A framework that's created and managed by you.
    CUSTOM = 2
  end
end

#supported_enforcement_modes::Array<::Google::Cloud::CloudSecurityCompliance::V1::EnforcementMode> (readonly)

Returns Output only. The supported enforcement modes of the framework.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 67

class Framework
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of framework.
  module FrameworkType
    # Default value. This value is unused.
    FRAMEWORK_TYPE_UNSPECIFIED = 0

    # A framework that's provided and managed by Google.
    BUILT_IN = 1

    # A framework that's created and managed by you.
    CUSTOM = 2
  end
end

#supported_target_resource_types::Array<::Google::Cloud::CloudSecurityCompliance::V1::TargetResourceType> (readonly)

Returns Output only. The target resource types that are supported by the framework.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 67

class Framework
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of framework.
  module FrameworkType
    # Default value. This value is unused.
    FRAMEWORK_TYPE_UNSPECIFIED = 0

    # A framework that's provided and managed by Google.
    BUILT_IN = 1

    # A framework that's created and managed by you.
    CUSTOM = 2
  end
end

#type::Google::Cloud::CloudSecurityCompliance::V1::Framework::FrameworkType (readonly)

Returns Output only. The type of framework.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 67

class Framework
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of framework.
  module FrameworkType
    # Default value. This value is unused.
    FRAMEWORK_TYPE_UNSPECIFIED = 0

    # A framework that's provided and managed by Google.
    BUILT_IN = 1

    # A framework that's created and managed by you.
    CUSTOM = 2
  end
end