Class: Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb

Overview

A framework audit.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_control_audit_details::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlAuditDetails>

Returns Optional. The details for the cloud controls within this audit.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#cloud_control_group_audit_details::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlGroupAuditDetails>

Returns Optional. The details for the cloud control groups within this audit.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#compliance_framework::String (readonly)

Returns Output only. The compliance framework used for the audit.

Returns:

  • (::String)

    Output only. The compliance framework used for the audit.



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#compliance_state::Google::Cloud::CloudSecurityCompliance::V1::ComplianceState (readonly)

Returns Output only. The overall compliance state of the audit.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#finish_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time that the audit finished.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#framework_audit_destination::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAuditDestination

Returns Required. The destination for the audit reports.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#framework_audit_id::String (readonly)

Returns Output only. The ID of the framework audit.

Returns:

  • (::String)

    Output only. The ID of the framework audit.



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#name::String (readonly)

Returns Output only. Identifier. The name of the framework audit.

Returns:

  • (::String)

    Output only. Identifier. The name of the framework audit.



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#operation_id::String (readonly)

Returns Output only. The ID of the long-running operation.

Returns:

  • (::String)

    Output only. The ID of the long-running operation.



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#report_summary::Google::Cloud::CloudSecurityCompliance::V1::ReportSummary (readonly)

Returns Output only. The summary of the report.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#scope::String (readonly)

Returns Output only. The scope of the audit.

Returns:

  • (::String)

    Output only. The scope of the audit.



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time that the audit started.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end

#state::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit::State (readonly)

Returns Output only. The framework audit state of the audit.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187

class FrameworkAudit
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the framework audit.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The audit is scheduled.
    SCHEDULED = 1

    # The audit is running.
    RUNNING = 2

    # The audit results are being uploaded.
    UPLOADING = 3

    # The audit failed.
    FAILED = 4

    # The audit completed successfully.
    SUCCEEDED = 5
  end
end