Class: Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceReport

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb

Overview

The response message for [GetFrameworkComplianceReport][].

Instance Attribute Summary collapse

Instance Attribute Details

#control_assessment_details::Google::Cloud::CloudSecurityCompliance::V1::ControlAssessmentDetails

Returns The control assessment details of the framework.

Returns:



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#framework::String

Returns The name of the framework.

Returns:

  • (::String)

    The name of the framework.



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#framework_categories::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkCategory>

Returns The list of framework categories supported.

Returns:



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#framework_description::String

Returns The description of the framework.

Returns:

  • (::String)

    The description of the framework.



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#framework_display_name::String

Returns Optional. The display name for the framework.

Returns:

  • (::String)

    Optional. The display name for the framework.



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#framework_type::Google::Cloud::CloudSecurityCompliance::V1::Framework::FrameworkType

Returns The type of framework.



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#major_revision_id::Integer

Returns The latest major revision ID of the framework.

Returns:

  • (::Integer)

    The latest major revision ID of the framework.



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#minor_revision_id::Integer

Returns The latest minor revision ID of the latest major revision of the framework.

Returns:

  • (::Integer)

    The latest minor revision ID of the latest major revision of the framework.



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The name of the framework compliance report.

Returns:

  • (::String)

    Identifier. The name of the framework compliance report.



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#supported_cloud_providers::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudProvider>

Returns The list of cloud providers supported by the framework.

Returns:



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_resource_details::Array<::Google::Cloud::CloudSecurityCompliance::V1::TargetResourceDetails>

Returns The target resource details of the framework.

Returns:



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The last updated time of the report.

Returns:



98
99
100
101
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 98

class FrameworkComplianceReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end