Class: Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummary

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb

Overview

The details for a framework compliance summary.

Instance Attribute Summary collapse

Instance Attribute Details

#control_assessment_details::Google::Cloud::CloudSecurityCompliance::V1::ControlAssessmentDetails

Returns The control assessment details of the framework.

Returns:



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#controls_passing_trend::Google::Cloud::CloudSecurityCompliance::V1::Trend (readonly)

Returns Output only. The trend of controls that are passing for the given duration.

Returns:



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#finding_count::Integer (readonly)

Returns Output only. The count of the findings generated against the framework.

Returns:

  • (::Integer)

    Output only. The count of the findings generated against the framework.



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#framework::String

Returns The name of the framework.

Returns:

  • (::String)

    The name of the framework.



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#framework_categories::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkCategory>

Returns The list of framework categories supported by the framework.

Returns:



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#framework_display_name::String

Returns Optional. The display name for the framework.

Returns:

  • (::String)

    Optional. The display name for the framework.



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#framework_type::Google::Cloud::CloudSecurityCompliance::V1::Framework::FrameworkType

Returns The type of framework.



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#major_revision_id::Integer

Returns The major revision ID of the framework.

Returns:

  • (::Integer)

    The major revision ID of the framework.



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#minor_revision_id::Integer

Returns The minor revision ID of the framework.

Returns:

  • (::Integer)

    The minor revision ID of the framework.



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The name of the framework compliance summary.

Returns:

  • (::String)

    Identifier. The name of the framework compliance summary.



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#supported_cloud_providers::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudProvider>

Returns The list of cloud providers supported by the framework.

Returns:



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_resource_details::Array<::Google::Cloud::CloudSecurityCompliance::V1::TargetResourceDetails>

Returns The target resource details for the framework.

Returns:



275
276
277
278
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275

class FrameworkComplianceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end