Class: Google::Cloud::CloudSecurityCompliance::V1::FrameworkReference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb

Overview

The reference of a framework, in one of the following formats:

  • organizations/{organization}/locations/{location}/frameworks/{framework}
  • projects/{project}/locations/{location}/frameworks/{framework}.

The only supported location is global.

Instance Attribute Summary collapse

Instance Attribute Details

#framework::String

Returns Required. The major version of the framework. If not specified, the version corresponds to the latest version of the framework.

Returns:

  • (::String)

    Required. The major version of the framework. If not specified, the version corresponds to the latest version of the framework.



120
121
122
123
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 120

class FrameworkReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#major_revision_id::Integer

Returns Optional. The major version of the framework. If not specified, the version corresponds to the latest version of the framework.

Returns:

  • (::Integer)

    Optional. The major version of the framework. If not specified, the version corresponds to the latest version of the framework.



120
121
122
123
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 120

class FrameworkReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end