Class: Google::Cloud::CloudSecurityCompliance::V1::GenerateFrameworkAuditScopeReportRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb

Overview

The request message for [GenerateFrameworkAuditScopeReport][].

Defined Under Namespace

Modules: Format

Instance Attribute Summary collapse

Instance Attribute Details

#compliance_framework::String

Returns Required. The compliance framework that the scope report is generated for.

Returns:

  • (::String)

    Required. The compliance framework that the scope report is generated for.



40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 40

class GenerateFrameworkAuditScopeReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The set of options for the audit scope report format.
  module Format
    # Default value. This value is unused.
    FORMAT_UNSPECIFIED = 0

    # The report format is the Open Document Format (ODF).
    ODF = 1
  end
end

#report_format::Google::Cloud::CloudSecurityCompliance::V1::GenerateFrameworkAuditScopeReportRequest::Format

Returns Required. The format that the scope report bytes is returned in.

Returns:



40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 40

class GenerateFrameworkAuditScopeReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The set of options for the audit scope report format.
  module Format
    # Default value. This value is unused.
    FORMAT_UNSPECIFIED = 0

    # The report format is the Open Document Format (ODF).
    ODF = 1
  end
end

#scope::String

Returns Required. The organization, folder or project for the audit report.

Supported formats are the following:

  • projects/{project_id}/locations/{location}
  • folders/{folder_id}/locations/{location}
  • organizations/{organization_id}/locations/{location}.

Returns:

  • (::String)

    Required. The organization, folder or project for the audit report.

    Supported formats are the following:

    • projects/{project_id}/locations/{location}
    • folders/{folder_id}/locations/{location}
    • organizations/{organization_id}/locations/{location}


40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 40

class GenerateFrameworkAuditScopeReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The set of options for the audit scope report format.
  module Format
    # Default value. This value is unused.
    FORMAT_UNSPECIFIED = 0

    # The report format is the Open Document Format (ODF).
    ODF = 1
  end
end