Class: Google::Cloud::CloudSecurityCompliance::V1::GenerateFrameworkAuditScopeReportResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb

Overview

The response message for [GenerateFrameworkAuditScopeReport][].

Instance Attribute Summary collapse

Instance Attribute Details

#compliance_framework::String

Returns Required. The compliance framework that the audit scope report is generated for.

Returns:

  • (::String)

    Required. The compliance framework that the audit scope report is generated for.



66
67
68
69
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 66

class GenerateFrameworkAuditScopeReportResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The name of the audit report, in the format that was given in the request.

Returns:

  • (::String)

    Identifier. The name of the audit report, in the format that was given in the request.



66
67
68
69
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 66

class GenerateFrameworkAuditScopeReportResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scope_report_contents::String

Returns The audit scope report content in byte format.

Returns:

  • (::String)

    The audit scope report content in byte format.



66
67
68
69
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 66

class GenerateFrameworkAuditScopeReportResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end