Class: Google::Cloud::CloudSecurityCompliance::V1::GetCloudControlDeploymentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb

Overview

The request message for [GetCloudControlDeployment][].

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name for the cloud control deployment, in the format organizations/{organization}/locations/{location}/cloudControlDeployments/{cloud_control_deployment} or projects/{project}/locations/{location}/cloudControlDeployments/{cloud_control_deployment}. The only supported location is global.

Returns:

  • (::String)

    Required. The name for the cloud control deployment, in the format organizations/{organization}/locations/{location}/cloudControlDeployments/{cloud_control_deployment} or projects/{project}/locations/{location}/cloudControlDeployments/{cloud_control_deployment}. The only supported location is global.



358
359
360
361
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 358

class GetCloudControlDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end