Class: Google::Cloud::CloudSecurityCompliance::V1::GetCloudControlRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb

Overview

The request message for [GetCloudControl][].

Instance Attribute Summary collapse

Instance Attribute Details

#major_revision_id::Integer

Returns Optional. The major version of the cloud control to retrieve. If not specified, the most recently updated revision_id is retrieved.

Returns:

  • (::Integer)

    Optional. The major version of the cloud control to retrieve. If not specified, the most recently updated revision_id is retrieved.



190
191
192
193
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 190

class GetCloudControlRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the cloud control to retrieve, in one of the following formats: organizations/{organization}/locations/{location}/cloudControls/{cloud_control} or projects/{project}/locations/{location}/cloudControls/{cloud_control}.

The only supported location is global.

Returns:

  • (::String)

    Required. The name of the cloud control to retrieve, in one of the following formats: organizations/{organization}/locations/{location}/cloudControls/{cloud_control} or projects/{project}/locations/{location}/cloudControls/{cloud_control}.

    The only supported location is global.



190
191
192
193
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 190

class GetCloudControlRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end