Class: Google::Cloud::CloudSecurityCompliance::V1::GetFrameworkDeploymentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb

Overview

The request message for [GetFrameworkDeployment][].

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the framework deployment, in the format organizations/{organization}/locations/{location}/frameworkDeployments/{framework_deployment} or projects/{project}/locations/{location}/frameworkDeployments/{framework_deployment}. The only supported location is global.

Returns:

  • (::String)

    Required. The name of the framework deployment, in the format organizations/{organization}/locations/{location}/frameworkDeployments/{framework_deployment} or projects/{project}/locations/{location}/frameworkDeployments/{framework_deployment}. The only supported location is global.



297
298
299
300
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 297

class GetFrameworkDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end