Class: Google::Cloud::CloudSecurityCompliance::V1::GetFrameworkRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb

Overview

The request message for [GetFramework][].

Instance Attribute Summary collapse

Instance Attribute Details

#major_revision_id::Integer

Returns Optional. The framework major version to retrieve. If not specified, the most recently updated revision_id is retrieved.

Returns:

  • (::Integer)

    Optional. The framework major version to retrieve. If not specified, the most recently updated revision_id is retrieved.



76
77
78
79
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 76

class GetFrameworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the framework to retrieve, in one of the following formats: organizations/{organization}/locations/{location}/frameworks/{framework} or projects/{project}/locations/{location}/frameworks/{framework}.

The only supported location is global.

Returns:

  • (::String)

    Required. The name of the framework to retrieve, in one of the following formats: organizations/{organization}/locations/{location}/frameworks/{framework} or projects/{project}/locations/{location}/frameworks/{framework}.

    The only supported location is global.



76
77
78
79
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 76

class GetFrameworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end