Class: Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb

Overview

The response message for [ListCloudControls][].

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_controls::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControl>

Returns The list of CloudControl resources.

Returns:



171
172
173
174
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 171

class ListCloudControlsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A pagination token. To retrieve the next page of results, call the method again with this token.

Returns:

  • (::String)

    A pagination token. To retrieve the next page of results, call the method again with this token.



171
172
173
174
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 171

class ListCloudControlsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end