Class: Google::Cloud::CloudSecurityCompliance::V1::ListFindingSummariesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ListFindingSummariesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb
Overview
The request message for [ListFindingSummaries][].
Instance Attribute Summary collapse
-
#end_time ⇒ ::Google::Protobuf::Timestamp
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#end_time ⇒ ::Google::Protobuf::Timestamp
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. The end time of the finding summary.
137 138 139 140 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 137 class ListFindingSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#filter ⇒ ::String
Returns Optional. The filtering results.
137 138 139 140 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 137 class ListFindingSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The requested page size. The server might return fewer items than requested. If unspecified, the server picks an appropriate default.
137 138 139 140 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 137 class ListFindingSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token that identifies the page of results that the server should return.
137 138 139 140 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 137 class ListFindingSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent scope for the framework overview page.
137 138 139 140 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 137 class ListFindingSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |