Class: Google::Cloud::CloudSecurityCompliance::V1::ListFindingSummariesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb

Overview

The response message for [ListFindingSummaries][].

Instance Attribute Summary collapse

Instance Attribute Details

#finding_summaries::Array<::Google::Cloud::CloudSecurityCompliance::V1::FindingSummary>

Returns List of finding summary by category.

Returns:



149
150
151
152
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 149

class ListFindingSummariesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String (readonly)

Returns Output only. The token to retrieve the next page of results.

Returns:

  • (::String)

    Output only. The token to retrieve the next page of results.



149
150
151
152
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 149

class ListFindingSummariesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end