Class: Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkComplianceSummariesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb

Overview

The response message for ListFrameworkComplianceSummariesResponse.

Instance Attribute Summary collapse

Instance Attribute Details

#framework_compliance_summaries::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummary>

Returns The list of framework compliance summaries.

Returns:



56
57
58
59
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 56

class ListFrameworkComplianceSummariesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String (readonly)

Returns Output only. The token to retrieve the next page of results.

Returns:

  • (::String)

    Output only. The token to retrieve the next page of results.



56
57
58
59
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 56

class ListFrameworkComplianceSummariesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end