Class: Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkDeploymentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb

Overview

The request message for [ListFrameworkDeployments][].

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. The filter to be applied on the resource, as defined by AIP-160: Filtering.

Returns:

  • (::String)

    Optional. The filter to be applied on the resource, as defined by AIP-160: Filtering.



332
333
334
335
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 332

class ListFrameworkDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. The sort order for the results. The following values are supported:

  • name
  • name desc

If you do not specify a value, then the results are not sorted.

Returns:

  • (::String)

    Optional. The sort order for the results. The following values are supported:

    • name
    • name desc

    If you do not specify a value, then the results are not sorted.



332
333
334
335
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 332

class ListFrameworkDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The requested page size. The server might return fewer items than requested. If unspecified, the server picks an appropriate default.

Returns:

  • (::Integer)

    Optional. The requested page size. The server might return fewer items than requested. If unspecified, the server picks an appropriate default.



332
333
334
335
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 332

class ListFrameworkDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Optional. A token that identifies a page of results the server should return.

Returns:

  • (::String)

    Optional. A token that identifies a page of results the server should return.



332
333
334
335
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 332

class ListFrameworkDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource of the framework deployment, in the format organizations/{organization}/locations/{location} or projects/{project}/locations/{location}. The only supported location is global.

Returns:

  • (::String)

    Required. The parent resource of the framework deployment, in the format organizations/{organization}/locations/{location} or projects/{project}/locations/{location}. The only supported location is global.



332
333
334
335
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 332

class ListFrameworkDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end