Class: Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkDeploymentsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb

Overview

The response message for [ListFrameworkDeployments][].

Instance Attribute Summary collapse

Instance Attribute Details

#framework_deployments::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment>

Returns The list of framework deployments.

Returns:



345
346
347
348
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 345

class ListFrameworkDeploymentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that identifies the next page of results that the server should return.

Returns:

  • (::String)

    A token that identifies the next page of results that the server should return.



345
346
347
348
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 345

class ListFrameworkDeploymentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end