Class: Google::Cloud::CloudSecurityCompliance::V1::Monitoring::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb

Overview

Client for the Monitoring service.

Service describing handlers for resources

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#folder_location_path, #framework_compliance_report_path, #location_path, #organization_location_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new Monitoring client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::CloudSecurityCompliance::V1::Monitoring::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::CloudSecurityCompliance::V1::Monitoring::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Monitoring client.

Yield Parameters:



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb', line 150

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/cloudsecuritycompliance/v1/monitoring_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @monitoring_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::CloudSecurityCompliance::V1::Monitoring::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @monitoring_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @monitoring_stub.endpoint
    config.universe_domain = @monitoring_stub.universe_domain
    config.logger = @monitoring_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Client)


214
215
216
# File 'lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb', line 214

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the Monitoring Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all Monitoring clients
::Google::Cloud::CloudSecurityCompliance::V1::Monitoring::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb', line 63

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "CloudSecurityCompliance", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.list_framework_compliance_summaries.timeout = 60.0
    default_config.rpcs.list_framework_compliance_summaries.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_finding_summaries.timeout = 60.0
    default_config.rpcs.list_finding_summaries.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.fetch_framework_compliance_report.timeout = 60.0
    default_config.rpcs.fetch_framework_compliance_report.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_control_compliance_summaries.timeout = 60.0
    default_config.rpcs.list_control_compliance_summaries.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.aggregate_framework_compliance_report.timeout = 60.0
    default_config.rpcs.aggregate_framework_compliance_report.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#aggregate_framework_compliance_report(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::AggregateFrameworkComplianceReportResponse #aggregate_framework_compliance_report(name: nil, interval: nil, filter: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::AggregateFrameworkComplianceReportResponse

Gets the aggregated compliance report over time for a given scope.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Monitoring::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::AggregateFrameworkComplianceReportRequest.new

# Call the aggregate_framework_compliance_report method.
result = client.aggregate_framework_compliance_report request

# The returned object is of type Google::Cloud::CloudSecurityCompliance::V1::AggregateFrameworkComplianceReportResponse.
p result

Overloads:

  • #aggregate_framework_compliance_report(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::AggregateFrameworkComplianceReportResponse

    Pass arguments to aggregate_framework_compliance_report via a request object, either of type AggregateFrameworkComplianceReportRequest or an equivalent Hash.

    Parameters:

  • #aggregate_framework_compliance_report(name: nil, interval: nil, filter: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::AggregateFrameworkComplianceReportResponse

    Pass arguments to aggregate_framework_compliance_report via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the aggregated compliance report over time to retrieve.

      The supported format is: organizations/{organization_id}/locations/{location}/frameworkComplianceReports/{framework_compliance_report}

    • interval (::Google::Type::Interval, ::Hash) (defaults to: nil)

      Optional. The start and end time range for the aggregated compliance report.

    • filter (::String) (defaults to: nil)

      Optional. The filtering results.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
# File 'lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb', line 672

def aggregate_framework_compliance_report request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::AggregateFrameworkComplianceReportRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.aggregate_framework_compliance_report..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.aggregate_framework_compliance_report.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.aggregate_framework_compliance_report.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @monitoring_stub.call_rpc :aggregate_framework_compliance_report, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the Monitoring Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



120
121
122
123
# File 'lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb', line 120

def configure
  yield @config if block_given?
  @config
end

#fetch_framework_compliance_report(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceReport #fetch_framework_compliance_report(name: nil, end_time: nil, filter: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceReport

Fetches the framework compliance report for a given scope.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Monitoring::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::FetchFrameworkComplianceReportRequest.new

# Call the fetch_framework_compliance_report method.
result = client.fetch_framework_compliance_report request

# The returned object is of type Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceReport.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
# File 'lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb', line 477

def fetch_framework_compliance_report request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::FetchFrameworkComplianceReportRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.fetch_framework_compliance_report..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.fetch_framework_compliance_report.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.fetch_framework_compliance_report.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @monitoring_stub.call_rpc :fetch_framework_compliance_report, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_control_compliance_summaries(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::ControlComplianceSummary> #list_control_compliance_summaries(parent: nil, end_time: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::ControlComplianceSummary>

Lists the control compliance summary for a given scope.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Monitoring::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::ListControlComplianceSummariesRequest.new

# Call the list_control_compliance_summaries method.
result = client.list_control_compliance_summaries request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudSecurityCompliance::V1::ControlComplianceSummary.
  p item
end

Overloads:

  • #list_control_compliance_summaries(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::ControlComplianceSummary>

    Pass arguments to list_control_compliance_summaries via a request object, either of type ListControlComplianceSummariesRequest or an equivalent Hash.

    Parameters:

  • #list_control_compliance_summaries(parent: nil, end_time: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::ControlComplianceSummary>

    Pass arguments to list_control_compliance_summaries via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent scope for the framework overview page.

    • end_time (::Google::Protobuf::Timestamp, ::Hash) (defaults to: nil)

      Optional. The end time of the control compliance summary.

    • page_size (::Integer) (defaults to: nil)

      Optional. The requested page size. The server might return fewer items than requested. If unspecified, the server picks an appropriate default.

    • page_token (::String) (defaults to: nil)

      Optional. A token that identifies the page of results that the server should return.

    • filter (::String) (defaults to: nil)

      Optional. The filtering results.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
# File 'lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb', line 576

def list_control_compliance_summaries request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListControlComplianceSummariesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_control_compliance_summaries..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_control_compliance_summaries.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_control_compliance_summaries.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @monitoring_stub.call_rpc :list_control_compliance_summaries, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @monitoring_stub, :list_control_compliance_summaries, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_finding_summaries(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FindingSummary> #list_finding_summaries(parent: nil, page_size: nil, page_token: nil, filter: nil, end_time: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FindingSummary>

Lists the finding summary by category for a given scope.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Monitoring::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::ListFindingSummariesRequest.new

# Call the list_finding_summaries method.
result = client.list_finding_summaries request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudSecurityCompliance::V1::FindingSummary.
  p item
end

Overloads:

  • #list_finding_summaries(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FindingSummary>

    Pass arguments to list_finding_summaries via a request object, either of type ListFindingSummariesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudSecurityCompliance::V1::ListFindingSummariesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_finding_summaries(parent: nil, page_size: nil, page_token: nil, filter: nil, end_time: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FindingSummary>

    Pass arguments to list_finding_summaries via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent scope for the framework overview page.

    • page_size (::Integer) (defaults to: nil)

      Optional. The requested page size. The server might return fewer items than requested. If unspecified, the server picks an appropriate default.

    • page_token (::String) (defaults to: nil)

      Optional. A token that identifies the page of results that the server should return.

    • filter (::String) (defaults to: nil)

      Optional. The filtering results.

    • end_time (::Google::Protobuf::Timestamp, ::Hash) (defaults to: nil)

      Optional. The end time of the finding summary.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb', line 386

def list_finding_summaries request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListFindingSummariesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_finding_summaries..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_finding_summaries.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_finding_summaries.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @monitoring_stub.call_rpc :list_finding_summaries, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @monitoring_stub, :list_finding_summaries, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_framework_compliance_summaries(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummary> #list_framework_compliance_summaries(parent: nil, page_size: nil, page_token: nil, filter: nil, view: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummary>

Lists the framework compliance summary for a given scope.

Examples:

Basic example

require "google/cloud/cloud_security_compliance/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudSecurityCompliance::V1::Monitoring::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkComplianceSummariesRequest.new

# Call the list_framework_compliance_summaries method.
result = client.list_framework_compliance_summaries request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummary.
  p item
end

Overloads:

  • #list_framework_compliance_summaries(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummary>

    Pass arguments to list_framework_compliance_summaries via a request object, either of type ListFrameworkComplianceSummariesRequest or an equivalent Hash.

    Parameters:

  • #list_framework_compliance_summaries(parent: nil, page_size: nil, page_token: nil, filter: nil, view: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummary>

    Pass arguments to list_framework_compliance_summaries via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent scope for the framework compliance summary.

    • page_size (::Integer) (defaults to: nil)

      Optional. The requested page size. The server might return fewer items than requested. If unspecified, the server picks an appropriate default.

    • page_token (::String) (defaults to: nil)

      Optional. A token that identifies the page of results that the server should return.

    • filter (::String) (defaults to: nil)

      Optional. The filtering results.

    • view (::Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummaryView) (defaults to: nil)

      Optional. Specifies the level of detail to return in the response.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb', line 285

def list_framework_compliance_summaries request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkComplianceSummariesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_framework_compliance_summaries..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_framework_compliance_summaries.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_framework_compliance_summaries.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @monitoring_stub.call_rpc :list_framework_compliance_summaries, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @monitoring_stub, :list_framework_compliance_summaries, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


221
222
223
# File 'lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb', line 221

def logger
  @monitoring_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


130
131
132
# File 'lib/google/cloud/cloud_security_compliance/v1/monitoring/client.rb', line 130

def universe_domain
  @monitoring_stub.universe_domain
end