Class: Google::Cloud::CloudSecurityCompliance::V1::OperationMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb

Overview

The metadata for the long-running operation.

Instance Attribute Summary collapse

Instance Attribute Details

#api_version::String (readonly)

Returns Output only. The API version that was used to start the operation.

Returns:

  • (::String)

    Output only. The API version that was used to start the operation.



460
461
462
463
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 460

class OperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the operation was created.

Returns:



460
461
462
463
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 460

class OperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the operation finished running.

Returns:



460
461
462
463
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 460

class OperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#requested_cancellation::Boolean (readonly)

Returns Output only. Identifies whether the user has requested that the operation be cancelled. If an operation was cancelled successfully, then the field google.longrunning.Operation.error contains the value [google.rpc.Code.CANCELLED][google.rpc.Code.CANCELLED].

Returns:

  • (::Boolean)

    Output only. Identifies whether the user has requested that the operation be cancelled. If an operation was cancelled successfully, then the field google.longrunning.Operation.error contains the value [google.rpc.Code.CANCELLED][google.rpc.Code.CANCELLED].



460
461
462
463
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 460

class OperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status_message::String (readonly)

Returns Output only. The human-readable status of the operation, if any.

Returns:

  • (::String)

    Output only. The human-readable status of the operation, if any.



460
461
462
463
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 460

class OperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target::String (readonly)

Returns Output only. The server-defined resource path for the target of the operation.

Returns:

  • (::String)

    Output only. The server-defined resource path for the target of the operation.



460
461
462
463
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 460

class OperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#verb::String (readonly)

Returns Output only. The name of the verb that was executed by the operation.

Returns:

  • (::String)

    Output only. The name of the verb that was executed by the operation.



460
461
462
463
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 460

class OperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end