Class: Google::Cloud::CloudSecurityCompliance::V1::PlaceholderSubstitutionRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb

Overview

The placeholder that's substituted in the rendered string.

Instance Attribute Summary collapse

Instance Attribute Details

#attribute::String

Returns The fully qualified proto attribute path, in dot notation.

Returns:

  • (::String)

    The fully qualified proto attribute path, in dot notation.



398
399
400
401
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 398

class PlaceholderSubstitutionRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end