Class: Google::Cloud::CloudSecurityCompliance::V1::ProjectCreationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb

Overview

The configuration that's required to create a project to be used as the target resource of a deployment.

Instance Attribute Summary collapse

Instance Attribute Details

#billing_account_id::String

Returns Required. The billing account ID for the project.

Returns:

  • (::String)

    Required. The billing account ID for the project.



226
227
228
229
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 226

class ProjectCreationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent of the project, in the format organizations/{organizationID} or folders/{folderID}.

Returns:

  • (::String)

    Required. The parent of the project, in the format organizations/{organizationID} or folders/{folderID}.



226
227
228
229
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 226

class ProjectCreationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project_display_name::String

Returns Required. The display name of the project.

Returns:

  • (::String)

    Required. The display name of the project.



226
227
228
229
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 226

class ProjectCreationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end