Class: Google::Cloud::CloudSecurityCompliance::V1::RegexpPattern

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb

Overview

The regular expression (regex) validator for parameter values.

Instance Attribute Summary collapse

Instance Attribute Details

#pattern::String

Returns Required. The regex pattern to match the values of the parameter with.

Returns:

  • (::String)

    Required. The regex pattern to match the values of the parameter with.



309
310
311
312
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 309

class RegexpPattern
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end