Class: Google::Cloud::CloudSecurityCompliance::V1::AggregateFrameworkComplianceReportRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::AggregateFrameworkComplianceReportRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb
Overview
The request message for [AggregateFrameworkComplianceReport][].
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#interval ⇒ ::Google::Type::Interval
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. The filtering results.
205 206 207 208 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 205 class AggregateFrameworkComplianceReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#interval ⇒ ::Google::Type::Interval
Returns Optional. The start and end time range for the aggregated compliance report.
205 206 207 208 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 205 class AggregateFrameworkComplianceReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the aggregated compliance report over time to retrieve.
The supported format is:
organizations/{organization_id}/locations/{location}/frameworkComplianceReports/{framework_compliance_report}.
205 206 207 208 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 205 class AggregateFrameworkComplianceReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |