Class: Google::Cloud::CloudSecurityCompliance::V1::Audit::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::Audit::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb
Overview
REST client for the Audit service.
Service describing handlers for resources
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
-
#operations_client ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Audit::Rest::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the Audit Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the Audit Client instance.
-
#create_framework_audit(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Creates an audit scope report for a framework.
-
#generate_framework_audit_scope_report(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::GenerateFrameworkAuditScopeReportResponse
Generates an audit scope report for a framework.
-
#get_framework_audit(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit
Gets the details for a framework audit.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new Audit REST client object.
-
#list_framework_audits(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit>
Lists the framework audits for a given organization, folder, or project.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#framework_audit_path, #location_path, #organization_location_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new Audit REST client object.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb', line 141 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = ::Google::Cloud::CloudSecurityCompliance::V1::Audit::Rest::Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @audit_stub = ::Google::Cloud::CloudSecurityCompliance::V1::Audit::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @audit_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @audit_stub.endpoint config.universe_domain = @audit_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @audit_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
211 212 213 |
# File 'lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb', line 211 def location_client @location_client end |
#operations_client ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Audit::Rest::Operations (readonly)
Get the associated client for long-running operations.
204 205 206 |
# File 'lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb', line 204 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the Audit Client class.
See Configuration for a description of the configuration fields.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb', line 65 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "CloudSecurityCompliance", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.generate_framework_audit_scope_report.timeout = 60.0 default_config.rpcs.create_framework_audit.timeout = 60.0 default_config.rpcs.list_framework_audits.timeout = 60.0 default_config.rpcs.list_framework_audits.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_framework_audit.timeout = 60.0 default_config.rpcs.get_framework_audit.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the Audit Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
111 112 113 114 |
# File 'lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb', line 111 def configure yield @config if block_given? @config end |
#create_framework_audit(request, options = nil) ⇒ ::Gapic::Operation #create_framework_audit(parent: nil, framework_audit_id: nil, framework_audit: nil) ⇒ ::Gapic::Operation
Creates an audit scope report for a framework.
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb', line 376 def create_framework_audit request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkAuditRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_framework_audit..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_framework_audit.timeout, metadata: , retry_policy: @config.rpcs.create_framework_audit.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @audit_stub.create_framework_audit request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#generate_framework_audit_scope_report(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::GenerateFrameworkAuditScopeReportResponse #generate_framework_audit_scope_report(scope: nil, report_format: nil, compliance_framework: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::GenerateFrameworkAuditScopeReportResponse
Generates an audit scope report for a framework.
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb', line 277 def generate_framework_audit_scope_report request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::GenerateFrameworkAuditScopeReportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.generate_framework_audit_scope_report..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.generate_framework_audit_scope_report.timeout, metadata: , retry_policy: @config.rpcs.generate_framework_audit_scope_report.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @audit_stub.generate_framework_audit_scope_report request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_framework_audit(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit #get_framework_audit(name: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit
Gets the details for a framework audit.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 |
# File 'lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb', line 566 def get_framework_audit request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::GetFrameworkAuditRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_framework_audit..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_framework_audit.timeout, metadata: , retry_policy: @config.rpcs.get_framework_audit.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @audit_stub.get_framework_audit request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_framework_audits(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit> #list_framework_audits(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit>
Lists the framework audits for a given organization, folder, or project.
480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb', line 480 def list_framework_audits request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkAuditsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_framework_audits..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_framework_audits.timeout, metadata: , retry_policy: @config.rpcs.list_framework_audits.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @audit_stub.list_framework_audits request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @audit_stub, :list_framework_audits, "framework_audits", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
218 219 220 |
# File 'lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb', line 218 def logger @audit_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
121 122 123 |
# File 'lib/google/cloud/cloud_security_compliance/v1/audit/rest/client.rb', line 121 def universe_domain @audit_stub.universe_domain end |