Class: Google::Cloud::CloudSecurityCompliance::V1::AuditConfig
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::AuditConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb
Overview
The audit configuration for Compliance Manager.
Defined Under Namespace
Classes: CmEligibleDestination
Instance Attribute Summary collapse
Instance Attribute Details
#destinations ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::AuditConfig::CmEligibleDestination>
Returns Required. The list of destinations that can be selected for uploading audit reports to.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb', line 90 class AuditConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The destination details where audit reports are # uploaded. # @!attribute [rw] gcs_bucket # @return [::String] # The Cloud Storage bucket where audit reports and evidences can be # uploaded. The format is `gs://{bucket_name}`. class CmEligibleDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |