Class: Google::Cloud::CloudSecurityCompliance::V1::AuditConfig::CmEligibleDestination
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::AuditConfig::CmEligibleDestination
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb
Overview
The destination details where audit reports are uploaded.
Instance Attribute Summary collapse
-
#gcs_bucket ⇒ ::String
The Cloud Storage bucket where audit reports and evidences can be uploaded.
Instance Attribute Details
#gcs_bucket ⇒ ::String
Returns The Cloud Storage bucket where audit reports and evidences can be
uploaded. The format is gs://{bucket_name}.
100 101 102 103 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb', line 100 class CmEligibleDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |