Class: Google::Cloud::CloudSecurityCompliance::V1::CloudControlReport
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::CloudControlReport
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb
Overview
The cloud control report.
Instance Attribute Summary collapse
-
#categories ⇒ ::Array<::String>
The list of categories for the cloud control.
-
#cloud_control ⇒ ::String
The name of the cloud control.
-
#cloud_control_assessment_details ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControlAssessmentDetails
The details of a cloud control assessment.
-
#cloud_control_deployment ⇒ ::String
The name of the cloud control deployment.
-
#cloud_control_type ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl::Type
The type of the cloud control.
-
#description ⇒ ::String
The description of the cloud control.
-
#display_name ⇒ ::String
The display name of the cloud control.
-
#enforcement_mode ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::EnforcementMode
The enforcement mode of the cloud control.
-
#finding_category ⇒ ::String
The category of the finding.
-
#finding_severity ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Severity
The severity of the finding.
-
#framework_major_revision_ids ⇒ ::Array<::Integer>
The major revision IDs of the frameworks that the cloud control belongs to.
-
#major_revision_id ⇒ ::Integer
The major revision ID of the cloud control.
-
#manual_cloud_control_assessment_details ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::ManualCloudControlAssessmentDetails
The details of a manual cloud control assessment.
-
#minor_revision_id ⇒ ::Integer
The minor revision ID of the cloud control.
-
#rules ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::Rule>
The list of rules that correspond to the cloud control.
-
#similar_controls ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::SimilarControls>
The list of similar controls.
Instance Attribute Details
#categories ⇒ ::Array<::String>
Returns The list of categories for the cloud control.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cloud_control ⇒ ::String
Returns The name of the cloud control.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cloud_control_assessment_details ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControlAssessmentDetails
Returns The details of a cloud control assessment.
Note: The following fields are mutually exclusive: cloud_control_assessment_details, manual_cloud_control_assessment_details. If a field in that set is populated, all other fields in the set will automatically be cleared.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cloud_control_deployment ⇒ ::String
Returns The name of the cloud control deployment.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cloud_control_type ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl::Type
Returns The type of the cloud control.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns The description of the cloud control.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns The display name of the cloud control.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enforcement_mode ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::EnforcementMode
Returns The enforcement mode of the cloud control.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#finding_category ⇒ ::String
Returns The category of the finding.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#finding_severity ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Severity
Returns The severity of the finding.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#framework_major_revision_ids ⇒ ::Array<::Integer>
Returns The major revision IDs of the frameworks that the cloud control belongs to.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#major_revision_id ⇒ ::Integer
Returns The major revision ID of the cloud control.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#manual_cloud_control_assessment_details ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::ManualCloudControlAssessmentDetails
Returns The details of a manual cloud control assessment.
Note: The following fields are mutually exclusive: manual_cloud_control_assessment_details, cloud_control_assessment_details. If a field in that set is populated, all other fields in the set will automatically be cleared.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#minor_revision_id ⇒ ::Integer
Returns The minor revision ID of the cloud control.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rules ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::Rule>
Returns The list of rules that correspond to the cloud control.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#similar_controls ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::SimilarControls>
Returns The list of similar controls.
400 401 402 403 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 400 class CloudControlReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |