Class: Google::Cloud::CloudSecurityCompliance::V1::CmEnrollment
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::CmEnrollment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb
Overview
The settings for Compliance Manager at a specific resource scope.=
Instance Attribute Summary collapse
-
#audit_config ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::AuditConfig
Optional.
-
#enrolled ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Identifier.
Instance Attribute Details
#audit_config ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::AuditConfig
Returns Optional. The audit configuration for Compliance Manager. If set at a scope, this configuration overrides any inherited audit configuration.
71 72 73 74 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb', line 71 class CmEnrollment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enrolled ⇒ ::Boolean
Returns Optional. Whether the resource is enrolled in Compliance Manager. This setting is inherited by all descendants.
71 72 73 74 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb', line 71 class CmEnrollment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The name of the Compliance Manager enrollment.
Supported formats are the following:
organizations/{organization_id}/locations/{location}/cmEnrollmentfolders/{folder_id}/locations/{location}/cmEnrollmentprojects/{project_id}/locations/{location}/cmEnrollment.
71 72 73 74 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb', line 71 class CmEnrollment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |