Class: Google::Cloud::CloudSecurityCompliance::V1::Config::Client
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::Config::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/cloud_security_compliance/v1/config/client.rb
Overview
Client for the Config service.
Config Service manages compliance frameworks, cloud controls, and their configurations.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the Config Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the Config Client instance.
-
#create_cloud_control(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Creates a custom cloud control in a given parent resource.
-
#create_framework(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Creates a custom framework in a given parent resource.
-
#delete_cloud_control(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a custom cloud control, including all its major and minor revisions.
-
#delete_framework(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a custom framework, including all its major and minor revisions.
-
#get_cloud_control(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Gets details about a cloud control.
-
#get_framework(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Gets details about a framework.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new Config client object.
-
#list_cloud_controls(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControl>
Lists the cloud controls (both built-in and custom) that are available in a given parent resource.
-
#list_frameworks(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::Framework>
Lists the frameworks (both built-in and custom) that are available within the parent resource.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_cloud_control(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Updates a custom cloud control.
-
#update_framework(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Updates a custom framework.
Methods included from Paths
#cloud_control_path, #framework_path, #location_path, #organization_location_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new Config client object.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 158 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/cloudsecuritycompliance/v1/config_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @config_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::CloudSecurityCompliance::V1::Config::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @config_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config_stub.endpoint config.universe_domain = @config_stub.universe_domain config.logger = @config_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Client (readonly)
Get the associated client for mix-in of the Locations.
222 223 224 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 222 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the Config Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "CloudSecurityCompliance", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.list_frameworks.timeout = 60.0 default_config.rpcs.list_frameworks.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_framework.timeout = 60.0 default_config.rpcs.get_framework.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.create_framework.timeout = 60.0 default_config.rpcs.update_framework.timeout = 60.0 default_config.rpcs.delete_framework.timeout = 60.0 default_config.rpcs.list_cloud_controls.timeout = 60.0 default_config.rpcs.list_cloud_controls.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_cloud_control.timeout = 60.0 default_config.rpcs.get_cloud_control.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.create_cloud_control.timeout = 60.0 default_config.rpcs.update_cloud_control.timeout = 60.0 default_config.rpcs.delete_cloud_control.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the Config Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
128 129 130 131 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 128 def configure yield @config if block_given? @config end |
#create_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl #create_cloud_control(parent: nil, cloud_control_id: nil, cloud_control: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Creates a custom cloud control in a given parent resource. You can't create built-in cloud controls because those are managed by Google.
1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 1005 def create_cloud_control request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::CreateCloudControlRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_cloud_control..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_cloud_control.timeout, metadata: , retry_policy: @config.rpcs.create_cloud_control.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.call_rpc :create_cloud_control, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#create_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework #create_framework(parent: nil, framework_id: nil, framework: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Creates a custom framework in a given parent resource. You can't create built-in frameworks because those are managed by Google.
495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 495 def create_framework request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_framework..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_framework.timeout, metadata: , retry_policy: @config.rpcs.create_framework.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.call_rpc :create_framework, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_cloud_control(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_cloud_control(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a custom cloud control, including all its major and minor revisions. Consider the following:
- You can't delete built-in cloud controls. You can only delete cloud
controls with type
CUSTOM. - You can't delete cloud controls if any of the versions are referenced by a framework.
- You can't restore a deleted cloud control. This action is permanent.
1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 1214 def delete_cloud_control request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::DeleteCloudControlRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_cloud_control..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_cloud_control.timeout, metadata: , retry_policy: @config.rpcs.delete_cloud_control.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.call_rpc :delete_cloud_control, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_framework(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_framework(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a custom framework, including all its major and minor revisions. Consider the following:
- You can't delete built-in frameworks. You can only delete frameworks
with type
CUSTOM. - You can't delete frameworks that are deployed to a resource.
- You can't restore a deleted framework. This action is permanent.
695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 695 def delete_framework request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::DeleteFrameworkRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_framework..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_framework.timeout, metadata: , retry_policy: @config.rpcs.delete_framework.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.call_rpc :delete_framework, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl #get_cloud_control(name: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Gets details about a cloud control. This method retrieves the latest major version of a cloud control that you identify by name.
By default, the latest major version of the cloud control is returned.
To retrieve a specific major version, include major_revision_id in
the request.
907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 907 def get_cloud_control request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::GetCloudControlRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_cloud_control..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_cloud_control.timeout, metadata: , retry_policy: @config.rpcs.get_cloud_control.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.call_rpc :get_cloud_control, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework #get_framework(name: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Gets details about a framework. This method retrieves the latest major version of the framework.
To retrieve a specific major version, include major_revision_id in
the request.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 399 def get_framework request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::GetFrameworkRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_framework..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_framework.timeout, metadata: , retry_policy: @config.rpcs.get_framework.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.call_rpc :get_framework, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_cloud_controls(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControl> #list_cloud_controls(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControl>
Lists the cloud controls (both built-in and custom) that are available in a given parent resource. The latest major version of each cloud control is returned. This method supports pagination.
805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 805 def list_cloud_controls request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_cloud_controls..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_cloud_controls.timeout, metadata: , retry_policy: @config.rpcs.list_cloud_controls.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.call_rpc :list_cloud_controls, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @config_stub, :list_cloud_controls, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_frameworks(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::Framework> #list_frameworks(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::Framework>
Lists the frameworks (both built-in and custom) that are available within the parent resource. The latest major version of each framework is returned. This method supports pagination.
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 299 def list_frameworks request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListFrameworksRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_frameworks..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_frameworks.timeout, metadata: , retry_policy: @config.rpcs.list_frameworks.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.call_rpc :list_frameworks, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @config_stub, :list_frameworks, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
229 230 231 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 229 def logger @config_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
138 139 140 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 138 def universe_domain @config_stub.universe_domain end |
#update_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl #update_cloud_control(update_mask: nil, cloud_control: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Updates a custom cloud control.
This method allows for partial updates of a cloud control. Use the
update_mask to specify which fields to update. Consider the following:
- If you provide an
update_mask, only the fields that are specified in the mask are updated. - If you don't provide an
update_mask, all the fields that are present in the request'scloud_controlbody are used to overwrite the existing resource.
You can only update cloud controls with the CUSTOM type.
A successful update creates a new version of the cloud control.
1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 1116 def update_cloud_control request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::UpdateCloudControlRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_cloud_control..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.cloud_control&.name header_params["cloud_control.name"] = request.cloud_control.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_cloud_control.timeout, metadata: , retry_policy: @config.rpcs.update_cloud_control.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.call_rpc :update_cloud_control, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework #update_framework(update_mask: nil, framework: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Updates a custom framework.
This method allows for partial updates of a framework. Use the
update_mask to specify which fields to update. Consider the following:
- If you provide an
update_mask, only the fields that are specified in the mask are updated. - If you don't provide an
update_mask, all the fields that are present in the request'sframeworkbody are used to overwrite the existing resource.
You can only update frameworks with the CUSTOM type.
A successful update creates a new version of the framework.
599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/client.rb', line 599 def update_framework request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::UpdateFrameworkRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_framework..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.framework&.name header_params["framework.name"] = request.framework.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_framework.timeout, metadata: , retry_policy: @config.rpcs.update_framework.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.call_rpc :update_framework, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |