Class: Google::Cloud::CloudSecurityCompliance::V1::Config::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::Config::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb
Overview
REST client for the Config service.
Config Service manages compliance frameworks, cloud controls, and their configurations.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the Config Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the Config Client instance.
-
#create_cloud_control(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Creates a custom cloud control in a given parent resource.
-
#create_framework(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Creates a custom framework in a given parent resource.
-
#delete_cloud_control(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a custom cloud control, including all its major and minor revisions.
-
#delete_framework(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a custom framework, including all its major and minor revisions.
-
#get_cloud_control(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Gets details about a cloud control.
-
#get_framework(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Gets details about a framework.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new Config REST client object.
-
#list_cloud_controls(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControl>
Lists the cloud controls (both built-in and custom) that are available in a given parent resource.
-
#list_frameworks(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::Framework>
Lists the frameworks (both built-in and custom) that are available within the parent resource.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_cloud_control(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Updates a custom cloud control.
-
#update_framework(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Updates a custom framework.
Methods included from Paths
#cloud_control_path, #framework_path, #location_path, #organization_location_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new Config REST client object.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 160 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @config_stub = ::Google::Cloud::CloudSecurityCompliance::V1::Config::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @config_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config_stub.endpoint config.universe_domain = @config_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @config_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
216 217 218 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 216 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the Config Client class.
See Configuration for a description of the configuration fields.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 66 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "CloudSecurityCompliance", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.list_frameworks.timeout = 60.0 default_config.rpcs.list_frameworks.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_framework.timeout = 60.0 default_config.rpcs.get_framework.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.create_framework.timeout = 60.0 default_config.rpcs.update_framework.timeout = 60.0 default_config.rpcs.delete_framework.timeout = 60.0 default_config.rpcs.list_cloud_controls.timeout = 60.0 default_config.rpcs.list_cloud_controls.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_cloud_control.timeout = 60.0 default_config.rpcs.get_cloud_control.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.create_cloud_control.timeout = 60.0 default_config.rpcs.update_cloud_control.timeout = 60.0 default_config.rpcs.delete_cloud_control.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the Config Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
130 131 132 133 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 130 def configure yield @config if block_given? @config end |
#create_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl #create_cloud_control(parent: nil, cloud_control_id: nil, cloud_control: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Creates a custom cloud control in a given parent resource. You can't create built-in cloud controls because those are managed by Google.
949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 949 def create_cloud_control request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::CreateCloudControlRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_cloud_control..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_cloud_control.timeout, metadata: , retry_policy: @config.rpcs.create_cloud_control.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.create_cloud_control request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#create_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework #create_framework(parent: nil, framework_id: nil, framework: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Creates a custom framework in a given parent resource. You can't create built-in frameworks because those are managed by Google.
474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 474 def create_framework request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_framework..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_framework.timeout, metadata: , retry_policy: @config.rpcs.create_framework.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.create_framework request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_cloud_control(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_cloud_control(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a custom cloud control, including all its major and minor revisions. Consider the following:
- You can't delete built-in cloud controls. You can only delete cloud
controls with type
CUSTOM. - You can't delete cloud controls if any of the versions are referenced by a framework.
- You can't restore a deleted cloud control. This action is permanent.
1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 1144 def delete_cloud_control request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::DeleteCloudControlRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_cloud_control..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_cloud_control.timeout, metadata: , retry_policy: @config.rpcs.delete_cloud_control.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.delete_cloud_control request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_framework(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_framework(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a custom framework, including all its major and minor revisions. Consider the following:
- You can't delete built-in frameworks. You can only delete frameworks
with type
CUSTOM. - You can't delete frameworks that are deployed to a resource.
- You can't restore a deleted framework. This action is permanent.
660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 660 def delete_framework request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::DeleteFrameworkRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_framework..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_framework.timeout, metadata: , retry_policy: @config.rpcs.delete_framework.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.delete_framework request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl #get_cloud_control(name: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Gets details about a cloud control. This method retrieves the latest major version of a cloud control that you identify by name.
By default, the latest major version of the cloud control is returned.
To retrieve a specific major version, include major_revision_id in
the request.
858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 858 def get_cloud_control request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::GetCloudControlRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_cloud_control..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_cloud_control.timeout, metadata: , retry_policy: @config.rpcs.get_cloud_control.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.get_cloud_control request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework #get_framework(name: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Gets details about a framework. This method retrieves the latest major version of the framework.
To retrieve a specific major version, include major_revision_id in
the request.
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 385 def get_framework request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::GetFrameworkRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_framework..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_framework.timeout, metadata: , retry_policy: @config.rpcs.get_framework.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.get_framework request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_cloud_controls(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControl> #list_cloud_controls(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::CloudControl>
Lists the cloud controls (both built-in and custom) that are available in a given parent resource. The latest major version of each cloud control is returned. This method supports pagination.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 763 def list_cloud_controls request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_cloud_controls..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_cloud_controls.timeout, metadata: , retry_policy: @config.rpcs.list_cloud_controls.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.list_cloud_controls request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @config_stub, :list_cloud_controls, "cloud_controls", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_frameworks(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::Framework> #list_frameworks(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::CloudSecurityCompliance::V1::Framework>
Lists the frameworks (both built-in and custom) that are available within the parent resource. The latest major version of each framework is returned. This method supports pagination.
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 292 def list_frameworks request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::ListFrameworksRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_frameworks..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_frameworks.timeout, metadata: , retry_policy: @config.rpcs.list_frameworks.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.list_frameworks request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @config_stub, :list_frameworks, "frameworks", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
223 224 225 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 223 def logger @config_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
140 141 142 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 140 def universe_domain @config_stub.universe_domain end |
#update_cloud_control(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl #update_cloud_control(update_mask: nil, cloud_control: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Updates a custom cloud control.
This method allows for partial updates of a cloud control. Use the
update_mask to specify which fields to update. Consider the following:
- If you provide an
update_mask, only the fields that are specified in the mask are updated. - If you don't provide an
update_mask, all the fields that are present in the request'scloud_controlbody are used to overwrite the existing resource.
You can only update cloud controls with the CUSTOM type.
A successful update creates a new version of the cloud control.
1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 1053 def update_cloud_control request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::UpdateCloudControlRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_cloud_control..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_cloud_control.timeout, metadata: , retry_policy: @config.rpcs.update_cloud_control.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.update_cloud_control request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#update_framework(request, options = nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework #update_framework(update_mask: nil, framework: nil, major_revision_id: nil) ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Updates a custom framework.
This method allows for partial updates of a framework. Use the
update_mask to specify which fields to update. Consider the following:
- If you provide an
update_mask, only the fields that are specified in the mask are updated. - If you don't provide an
update_mask, all the fields that are present in the request'sframeworkbody are used to overwrite the existing resource.
You can only update frameworks with the CUSTOM type.
A successful update creates a new version of the framework.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 |
# File 'lib/google/cloud/cloud_security_compliance/v1/config/rest/client.rb', line 571 def update_framework request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudSecurityCompliance::V1::UpdateFrameworkRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_framework..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::CloudSecurityCompliance::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_framework.timeout, metadata: , retry_policy: @config.rpcs.update_framework.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @config_stub.update_framework request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |