Class: Google::Cloud::CloudSecurityCompliance::V1::ControlAssessmentDetails
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ControlAssessmentDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb
Overview
The details for a control assessment.
Instance Attribute Summary collapse
-
#assessed_passing_controls ⇒ ::Integer
The number of controls that were assessed and are passing.
-
#failing_controls ⇒ ::Integer
The number of controls that are failing.
-
#not_assessed_controls ⇒ ::Integer
The number of controls that aren't assessed because they require manual review.
-
#passing_controls ⇒ ::Integer
The number of controls that are passing or not assessed.
Instance Attribute Details
#assessed_passing_controls ⇒ ::Integer
Returns The number of controls that were assessed and are passing.
233 234 235 236 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 233 class ControlAssessmentDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#failing_controls ⇒ ::Integer
Returns The number of controls that are failing.
233 234 235 236 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 233 class ControlAssessmentDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#not_assessed_controls ⇒ ::Integer
Returns The number of controls that aren't assessed because they require manual review.
233 234 235 236 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 233 class ControlAssessmentDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#passing_controls ⇒ ::Integer
Returns The number of controls that are passing or not assessed.
233 234 235 236 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 233 class ControlAssessmentDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |