Class: Google::Cloud::CloudSecurityCompliance::V1::ControlComplianceSummary
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ControlComplianceSummary
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb
Overview
The details for control compliance.
Instance Attribute Summary collapse
-
#cloud_control_reports ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlReport>
The list of cloud control reports.
-
#compliance_frameworks ⇒ ::Array<::String>
The list of compliance frameworks that the control belongs to.
-
#control ⇒ ::String
The name of the control.
-
#control_responsibility_type ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::RegulatoryControlResponsibilityType
The responsibility type for the control.
-
#description ⇒ ::String
The description of the control.
-
#display_name ⇒ ::String
The display name of the control.
-
#is_fake_control ⇒ ::Boolean
Whether the control is a fake control.
-
#name ⇒ ::String
Identifier.
-
#overall_evaluation_state ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::EvaluationState
readonly
Output only.
-
#similar_controls ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::SimilarControls>
The list of similar controls.
-
#total_findings_count ⇒ ::Integer
The total number of findings for the control.
Instance Attribute Details
#cloud_control_reports ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlReport>
Returns The list of cloud control reports.
342 343 344 345 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 342 class ControlComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#compliance_frameworks ⇒ ::Array<::String>
Returns The list of compliance frameworks that the control belongs to.
342 343 344 345 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 342 class ControlComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#control ⇒ ::String
Returns The name of the control.
342 343 344 345 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 342 class ControlComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#control_responsibility_type ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::RegulatoryControlResponsibilityType
Returns The responsibility type for the control.
342 343 344 345 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 342 class ControlComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns The description of the control.
342 343 344 345 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 342 class ControlComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns The display name of the control.
342 343 344 345 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 342 class ControlComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#is_fake_control ⇒ ::Boolean
Returns Whether the control is a fake control. Fake controls are created and mapped to cloud controls that don't belong to a control group.
342 343 344 345 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 342 class ControlComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The name of the control compliance summary.
342 343 344 345 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 342 class ControlComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#overall_evaluation_state ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::EvaluationState (readonly)
Returns Output only. The overall evaluation status of the control.
342 343 344 345 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 342 class ControlComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#similar_controls ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::SimilarControls>
Returns The list of similar controls.
342 343 344 345 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 342 class ControlComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_findings_count ⇒ ::Integer
Returns The total number of findings for the control.
342 343 344 345 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 342 class ControlComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |