Class: Google::Cloud::CloudSecurityCompliance::V1::CreateCloudControlRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::CreateCloudControlRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb
Overview
The request message for [CreateCloudControl][].
Instance Attribute Summary collapse
-
#cloud_control ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Required.
-
#cloud_control_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#cloud_control ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Returns Required. The cloud control that's being created.
211 212 213 214 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 211 class CreateCloudControlRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cloud_control_id ⇒ ::String
Returns Required. The identifier for the cloud control, which is the last segment
of the cloud control name. The format is
^[a-zA-Z][a-zA-Z0-9-]{0,61}[a-zA-Z0-9]$.
211 212 213 214 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 211 class CreateCloudControlRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource name, in one of the following formats:
organizations/{organization}/locations/{location}.projects/{project}/locations/{location}.
The only supported location is global.
211 212 213 214 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 211 class CreateCloudControlRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |