Class: Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkAuditRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkAuditRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb
Overview
The request message for [CreateFrameworkAudit][].
Instance Attribute Summary collapse
-
#framework_audit ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit
Required.
-
#framework_audit_id ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#framework_audit ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit
Returns Required. The framework audit to create.
112 113 114 115 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 112 class CreateFrameworkAuditRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#framework_audit_id ⇒ ::String
Returns Optional. The ID to use for the framework audit. The ID becomes the final component of the framework audit's full resource name.
The ID must be between 4-63 characters, and valid characters
are \[a-z][0-9]-\.
112 113 114 115 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 112 class CreateFrameworkAuditRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource where this framework audit is created.
Supported formats are the following:
organizations/{organization_id}/locations/{location}folders/{folder_id}/locations/{location}projects/{project_id}/locations/{location}.
112 113 114 115 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 112 class CreateFrameworkAuditRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |