Class: Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::CreateFrameworkRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb
Overview
The request message for [CreateFramework][].
Instance Attribute Summary collapse
-
#framework ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Required.
-
#framework_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#framework ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Returns Required. The resource being created.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 96 class CreateFrameworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#framework_id ⇒ ::String
Returns Required. The identifier (ID) of the framework. The ID is not the full name of the framework; it's the last part of the full name of the framework.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 96 class CreateFrameworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource name, in one of the following formats:
organizations/{organization}/locations/{location}projects/{project}/locations/{location}.
The only supported location is global.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 96 class CreateFrameworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |