Module: Google::Cloud::CloudSecurityCompliance::V1::DeploymentState
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb
Overview
The state of the deployment resource.
Constant Summary collapse
- DEPLOYMENT_STATE_UNSPECIFIED =
Default value. This value is unused.
0- DEPLOYMENT_STATE_VALIDATING =
Validating the deployment.
1- DEPLOYMENT_STATE_CREATING =
Deployment is being created.
2- DEPLOYMENT_STATE_DELETING =
Deployment is being deleted.
3- DEPLOYMENT_STATE_UPDATING =
Deployment is being updated.
8- DEPLOYMENT_STATE_FAILED =
Deployment has failed. All the changes made by the deployment were successfully rolled back. You can retry or delete a deployment that's in this state.
4- DEPLOYMENT_STATE_READY =
Deployment is successful and ready to use.
5- DEPLOYMENT_STATE_PARTIALLY_DEPLOYED =
Deployment is partially deployed. All the cloud controls weren't deployed successfully. Retrying the operation resumes from the first failed step.
6- DEPLOYMENT_STATE_PARTIALLY_DELETED =
Deployment is partially deleted. All the cloud control deployments weren't deleted successfully. Retrying the operation resumes from the first failed step.
7