Class: Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb
Overview
A framework audit.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#cloud_control_audit_details ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlAuditDetails>
Optional.
-
#cloud_control_group_audit_details ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlGroupAuditDetails>
Optional.
-
#compliance_framework ⇒ ::String
readonly
Output only.
-
#compliance_state ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::ComplianceState
readonly
Output only.
-
#finish_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#framework_audit_destination ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAuditDestination
Required.
-
#framework_audit_id ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#operation_id ⇒ ::String
readonly
Output only.
-
#report_summary ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::ReportSummary
readonly
Output only.
-
#scope ⇒ ::String
readonly
Output only.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#state ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit::State
readonly
Output only.
Instance Attribute Details
#cloud_control_audit_details ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlAuditDetails>
Returns Optional. The details for the cloud controls within this audit.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#cloud_control_group_audit_details ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlGroupAuditDetails>
Returns Optional. The details for the cloud control groups within this audit.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#compliance_framework ⇒ ::String (readonly)
Returns Output only. The compliance framework used for the audit.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#compliance_state ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::ComplianceState (readonly)
Returns Output only. The overall compliance state of the audit.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#finish_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time that the audit finished.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#framework_audit_destination ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAuditDestination
Returns Required. The destination for the audit reports.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#framework_audit_id ⇒ ::String (readonly)
Returns Output only. The ID of the framework audit.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#name ⇒ ::String (readonly)
Returns Output only. Identifier. The name of the framework audit.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#operation_id ⇒ ::String (readonly)
Returns Output only. The ID of the long-running operation.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#report_summary ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::ReportSummary (readonly)
Returns Output only. The summary of the report.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#scope ⇒ ::String (readonly)
Returns Output only. The scope of the audit.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time that the audit started.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |
#state ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit::State (readonly)
Returns Output only. The framework audit state of the audit.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 187 class FrameworkAudit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the framework audit. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The audit is scheduled. SCHEDULED = 1 # The audit is running. RUNNING = 2 # The audit results are being uploaded. UPLOADING = 3 # The audit failed. FAILED = 4 # The audit completed successfully. SUCCEEDED = 5 end end |