Class: Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummary
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummary
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb
Overview
The details for a framework compliance summary.
Instance Attribute Summary collapse
-
#control_assessment_details ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::ControlAssessmentDetails
The control assessment details of the framework.
-
#controls_passing_trend ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Trend
readonly
Output only.
-
#finding_count ⇒ ::Integer
readonly
Output only.
-
#framework ⇒ ::String
The name of the framework.
-
#framework_categories ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkCategory>
The list of framework categories supported by the framework.
-
#framework_display_name ⇒ ::String
Optional.
-
#framework_type ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework::FrameworkType
The type of framework.
-
#major_revision_id ⇒ ::Integer
The major revision ID of the framework.
-
#minor_revision_id ⇒ ::Integer
The minor revision ID of the framework.
-
#name ⇒ ::String
Identifier.
-
#supported_cloud_providers ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudProvider>
The list of cloud providers supported by the framework.
-
#target_resource_details ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::TargetResourceDetails>
The target resource details for the framework.
Instance Attribute Details
#control_assessment_details ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::ControlAssessmentDetails
Returns The control assessment details of the framework.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#controls_passing_trend ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Trend (readonly)
Returns Output only. The trend of controls that are passing for the given duration.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#finding_count ⇒ ::Integer (readonly)
Returns Output only. The count of the findings generated against the framework.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#framework ⇒ ::String
Returns The name of the framework.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#framework_categories ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkCategory>
Returns The list of framework categories supported by the framework.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#framework_display_name ⇒ ::String
Returns Optional. The display name for the framework.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#framework_type ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework::FrameworkType
Returns The type of framework.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#major_revision_id ⇒ ::Integer
Returns The major revision ID of the framework.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#minor_revision_id ⇒ ::Integer
Returns The minor revision ID of the framework.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The name of the framework compliance summary.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#supported_cloud_providers ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudProvider>
Returns The list of cloud providers supported by the framework.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_resource_details ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::TargetResourceDetails>
Returns The target resource details for the framework.
275 276 277 278 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 275 class FrameworkComplianceSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |