Class: Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb
Overview
Framework deployments represent the assignment of a framework to a target resource. Supported target resources are organizations, folders, and projects.
Instance Attribute Summary collapse
-
#cloud_control_deployment_references ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeploymentReference>
readonly
Output only.
-
#cloud_control_metadata ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlMetadata>
Required.
-
#computed_target_resource ⇒ ::String
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#deployment_state ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::DeploymentState
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#etag ⇒ ::String
Optional.
-
#framework ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkReference
Required.
-
#name ⇒ ::String
Identifier.
-
#target_resource_config ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::TargetResourceConfig
Required.
-
#target_resource_display_name ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#cloud_control_deployment_references ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeploymentReference> (readonly)
Returns Output only. The references to the cloud control deployments. The reference includes all the cloud control deployments that are in the framework or in a cloud control group.
For example, if a framework deployment deploys two
cloud controls, cc-deployment-1 and cc-deployment-2, then the
references are:
{
cloud_control_deployment_reference: {
cloud_control_deployment:
"organizations/\\{organization}/locations/\\{location}/cloudControlDeployments/cc-deployment-1"
},
cloud_control_deployment_reference: {
cloud_control_deployment:
"organizations/\\{organization}/locations/\\{location}/cloudControlDeployments/cc-deployment-2"
}
```.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cloud_control_metadata ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlMetadata>
Returns Required. The deployment mode and parameters for each of the cloud controls in the framework. Every cloud control in the framework includes metadata.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#computed_target_resource ⇒ ::String (readonly)
Returns Output only. The target resource to deploy the framework to, in one the following formats:
organizations/{organizationID}folders/{folderID}projects/{projectID}.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the resource was created.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#deployment_state ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::DeploymentState (readonly)
Returns Output only. The state for the framework deployment.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. A user-provided description of the framework deployment.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#etag ⇒ ::String
Returns Optional. To prevent concurrent updates from overwriting each other, always
provide the etag when you update a framework deployment. You can also
provide the etag when you delete a framework deployment, to help
ensure that you're deleting the intended version of the
framework deployment.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#framework ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkReference
Returns Required. A reference to the framework that you're deploying.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The name of the framework deployment, in the format
organizations/{organization}/locations/{location}/frameworkDeployments/{framework_deployment}
or
projects/{project}/locations/{location}/frameworkDeployments/{framework_deployment}.
The only supported location is global.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_resource_config ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::TargetResourceConfig
Returns Required. The details of the target resource that you want to deploy the framework to. You can specify an existing resource, or create a new one.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_resource_display_name ⇒ ::String (readonly)
Returns Output only. The display name of the target resource.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the resource last updated.
96 97 98 99 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 96 class FrameworkDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |