Class: Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeploymentReference
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeploymentReference
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb
Overview
The reference to a framework deployment.
Instance Attribute Summary collapse
-
#framework_deployment ⇒ ::String
readonly
Output only.
-
#framework_display_name ⇒ ::String
Optional.
-
#framework_reference ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkReference
Optional.
Instance Attribute Details
#framework_deployment ⇒ ::String (readonly)
Returns Output only. The name of the framework deployment, in the format
organizations/{organization}/locations/{location}/frameworkDeployments/{framework_deployment}
or
projects/{project}/locations/{location}/frameworkDeployments/{framework_deployment}.
The only supported location is global.
449 450 451 452 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 449 class FrameworkDeploymentReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#framework_display_name ⇒ ::String
Returns Optional. The display name of the framework that this framework deployment is for.
449 450 451 452 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 449 class FrameworkDeploymentReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#framework_reference ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkReference
Returns Optional. The reference to the framework that this deployment is for. For example:
{
framework:
"organizations/\\{organization}/locations/\\{location}/frameworks/\\{framework}",
major_revision_id: 1
}
The only supported location is global.
449 450 451 452 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 449 class FrameworkDeploymentReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |