Module: Google::Cloud::CloudSecurityCompliance::V1::GenerateFrameworkAuditScopeReportRequest::Format
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb
Overview
The set of options for the audit scope report format.
Constant Summary collapse
- FORMAT_UNSPECIFIED =
Default value. This value is unused.
0- ODF =
The report format is the Open Document Format (ODF).
1