Class: Google::Cloud::CloudSecurityCompliance::V1::IntRange
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::IntRange
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb
Overview
The number range for number parameters.
Instance Attribute Summary collapse
-
#max ⇒ ::Integer
Required.
-
#min ⇒ ::Integer
Required.
Instance Attribute Details
#max ⇒ ::Integer
Returns Required. The maximum permitted value for the numeric parameter (inclusive).
323 324 325 326 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 323 class IntRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min ⇒ ::Integer
Returns Required. The minimum permitted value for the numeric parameter (inclusive).
323 324 325 326 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 323 class IntRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |