Class: Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlDeploymentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb
Overview
The response message for [ListCloudControlDeployments][].
Instance Attribute Summary collapse
-
#cloud_control_deployments ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment>
The list of cloud control deployments.
-
#next_page_token ⇒ ::String
A token that identifies the next page of results that the server should return.
Instance Attribute Details
#cloud_control_deployments ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::CloudControlDeployment>
Returns The list of cloud control deployments.
405 406 407 408 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 405 class ListCloudControlDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that identifies the next page of results that the server should return.
405 406 407 408 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 405 class ListCloudControlDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |