Class: Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ListCloudControlsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb
Overview
Request message for [ListCloudControls][].
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. The maximum number of cloud controls to return. The default value
is 500.
If you exceed the maximum value of 1000, then the service uses the
maximum value.
158 159 160 161 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 158 class ListCloudControlsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A pagination token that's returned from a previous request to list cloud controls. Provide this token to retrieve the next page of results.
When paginating, the parent that you provide to the ListCloudControls request must match the call that provided the page token.
158 159 160 161 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 158 class ListCloudControlsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource name, in one of the following formats:
organizations/{organization}/locations/{location}projects/{project}/locations/{location}.
The only supported location is global.
158 159 160 161 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 158 class ListCloudControlsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |