Class: Google::Cloud::CloudSecurityCompliance::V1::ListControlComplianceSummariesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ListControlComplianceSummariesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb
Overview
The request message for [ListControlComplianceSummaries][].
Instance Attribute Summary collapse
-
#end_time ⇒ ::Google::Protobuf::Timestamp
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#end_time ⇒ ::Google::Protobuf::Timestamp
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. The end time of the control compliance summary.
173 174 175 176 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 173 class ListControlComplianceSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#filter ⇒ ::String
Returns Optional. The filtering results.
173 174 175 176 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 173 class ListControlComplianceSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The requested page size. The server might return fewer items than requested. If unspecified, the server picks an appropriate default.
173 174 175 176 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 173 class ListControlComplianceSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token that identifies the page of results that the server should return.
173 174 175 176 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 173 class ListControlComplianceSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent scope for the framework overview page.
173 174 175 176 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 173 class ListControlComplianceSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |