Class: Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkAuditsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkAuditsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb
Overview
The request message for [ListFrameworkAudits][].
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. The filters to apply to the framework audits.
Supported filters are compliance_framework, compliance_state,
create_time, and framework_audit_name. If the filter is invalid, an
invalid argument error is returned.
For syntax details, see [AIP-160][https://google.aip.dev/160].
240 241 242 243 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 240 class ListFrameworkAuditsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of framework audits to return. The service might return fewer audits than this value. If unspecified, a maximum of 10 framework audits are returned. The maximum value is 50; values above 50 are limited to 50.
240 241 242 243 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 240 class ListFrameworkAuditsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. The next_page_token value that's returned from a previous list
request, if any.
240 241 242 243 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 240 class ListFrameworkAuditsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource where the framework audits are listed.
Supported formats are the following:
organizations/{organization_id}/locations/{location}folders/{folder_id}/locations/{location}projects/{project_id}/locations/{location}.
240 241 242 243 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 240 class ListFrameworkAuditsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |