Class: Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkAuditsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkAuditsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb
Overview
The response message for [ListFrameworkAudits][].
Instance Attribute Summary collapse
-
#framework_audits ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit>
The framework audits.
-
#next_page_token ⇒ ::String
A token, which you can send as the
page_tokento retrieve the next page.
Instance Attribute Details
#framework_audits ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkAudit>
Returns The framework audits.
253 254 255 256 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 253 class ListFrameworkAuditsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which you can send as the page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
253 254 255 256 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/audit.rb', line 253 class ListFrameworkAuditsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |