Class: Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkComplianceSummariesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkComplianceSummariesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb
Overview
The request message for ListFrameworkComplianceSummariesRequest.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#view ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummaryView
Optional.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. The filtering results.
43 44 45 46 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 43 class ListFrameworkComplianceSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The requested page size. The server might return fewer items than requested. If unspecified, the server picks an appropriate default.
43 44 45 46 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 43 class ListFrameworkComplianceSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token that identifies the page of results that the server should return.
43 44 45 46 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 43 class ListFrameworkComplianceSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent scope for the framework compliance summary.
43 44 45 46 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 43 class ListFrameworkComplianceSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#view ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::FrameworkComplianceSummaryView
Returns Optional. Specifies the level of detail to return in the response.
43 44 45 46 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/monitoring.rb', line 43 class ListFrameworkComplianceSummariesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |