Class: Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ListFrameworkDeploymentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb
Overview
The response message for [ListFrameworkDeployments][].
Instance Attribute Summary collapse
-
#framework_deployments ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment>
The list of framework deployments.
-
#next_page_token ⇒ ::String
A token that identifies the next page of results that the server should return.
Instance Attribute Details
#framework_deployments ⇒ ::Array<::Google::Cloud::CloudSecurityCompliance::V1::FrameworkDeployment>
Returns The list of framework deployments.
345 346 347 348 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 345 class ListFrameworkDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that identifies the next page of results that the server should return.
345 346 347 348 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 345 class ListFrameworkDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |