Class: Google::Cloud::CloudSecurityCompliance::V1::ListFrameworksRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ListFrameworksRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb
Overview
Request message for [ListFrameworks][].
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. The maximum number of frameworks to return. The default value is
500.
If you exceed the maximum value of 1000, then the service uses the
maximum value.
43 44 45 46 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 43 class ListFrameworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A pagination token returned from a previous request to list frameworks. Provide this token to retrieve the next page of results.
43 44 45 46 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 43 class ListFrameworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource name, in one of the following formats:
organizations/{organization}/locations/{location}projects/{project}/locations/{location}.
The only supported location is global.
43 44 45 46 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 43 class ListFrameworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |