Class: Google::Cloud::CloudSecurityCompliance::V1::ParamValue
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ParamValue
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb
Overview
The possible parameter value types.
Instance Attribute Summary collapse
-
#bool_value ⇒ ::Boolean
Optional.
-
#number_value ⇒ ::Float
Optional.
-
#oneof_value ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Parameter
Optional.
-
#string_list_value ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::StringList
Optional.
-
#string_value ⇒ ::String
Optional.
Instance Attribute Details
#bool_value ⇒ ::Boolean
Returns Optional. A boolean value.
Note: The following fields are mutually exclusive: bool_value, string_value, string_list_value, number_value, oneof_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
363 364 365 366 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 363 class ParamValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#number_value ⇒ ::Float
Returns Optional. A double value.
Note: The following fields are mutually exclusive: number_value, string_value, bool_value, string_list_value, oneof_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
363 364 365 366 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 363 class ParamValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#oneof_value ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Parameter
Returns Optional. Sub-parameter values.
Note: The following fields are mutually exclusive: oneof_value, string_value, bool_value, string_list_value, number_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
363 364 365 366 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 363 class ParamValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#string_list_value ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::StringList
Returns Optional. A repeated string.
Note: The following fields are mutually exclusive: string_list_value, string_value, bool_value, number_value, oneof_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
363 364 365 366 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 363 class ParamValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#string_value ⇒ ::String
Returns Optional. A string value.
Note: The following fields are mutually exclusive: string_value, bool_value, string_list_value, number_value, oneof_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
363 364 365 366 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 363 class ParamValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |