Class: Google::Cloud::CloudSecurityCompliance::V1::ParameterSubstitutionRule
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::ParameterSubstitutionRule
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb
Overview
The parameter substitution rules.
Instance Attribute Summary collapse
-
#attribute_substitution_rule ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::AttributeSubstitutionRule
The attribute substitution rule.
-
#placeholder_substitution_rule ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::PlaceholderSubstitutionRule
The placeholder substitution rule.
Instance Attribute Details
#attribute_substitution_rule ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::AttributeSubstitutionRule
Returns The attribute substitution rule.
Note: The following fields are mutually exclusive: attribute_substitution_rule, placeholder_substitution_rule. If a field in that set is populated, all other fields in the set will automatically be cleared.
379 380 381 382 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 379 class ParameterSubstitutionRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#placeholder_substitution_rule ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::PlaceholderSubstitutionRule
Returns The placeholder substitution rule.
Note: The following fields are mutually exclusive: placeholder_substitution_rule, attribute_substitution_rule. If a field in that set is populated, all other fields in the set will automatically be cleared.
379 380 381 382 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 379 class ParameterSubstitutionRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |