Class: Google::Cloud::CloudSecurityCompliance::V1::TargetResourceConfig
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::TargetResourceConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb
Overview
The name of the target resource or the configuration that's required to create a new target resource.
Instance Attribute Summary collapse
-
#existing_target_resource ⇒ ::String
Optional.
-
#target_resource_creation_config ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::TargetResourceCreationConfig
Optional.
Instance Attribute Details
#existing_target_resource ⇒ ::String
Returns Optional. The resource hierarchy node, in one of the following formats:
organizations/{organizationID}folders/{folderID}projects/{projectID}
Note: The following fields are mutually exclusive: existing_target_resource, target_resource_creation_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
179 180 181 182 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 179 class TargetResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_resource_creation_config ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::TargetResourceCreationConfig
Returns Optional. The details that are required to create a resource and use that resource as the target resource for deployment.
Note: The following fields are mutually exclusive: target_resource_creation_config, existing_target_resource. If a field in that set is populated, all other fields in the set will automatically be cleared.
179 180 181 182 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/deployment.rb', line 179 class TargetResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |