Class: Google::Cloud::CloudSecurityCompliance::V1::UpdateCloudControlRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::UpdateCloudControlRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb
Overview
The request message for [UpdateCloudControl][].
Instance Attribute Summary collapse
-
#cloud_control ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#cloud_control ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CloudControl
Returns Required. The cloud control that you're updating.
236 237 238 239 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 236 class UpdateCloudControlRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Use a field mask to specify the fields to be overwritten in the
cloud control during the update.
The fields that you specify in the update_mask are relative to the
cloud control, not the full request. A field is overwritten if it is in
the mask. If you don't provide a mask, all fields in the request
are updated.
You can update the following fields:
- Display name
- Description
- Parameters
- Rules
- Parameter specification.
236 237 238 239 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 236 class UpdateCloudControlRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |