Class: Google::Cloud::CloudSecurityCompliance::V1::UpdateCmEnrollmentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::UpdateCmEnrollmentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb
Overview
The request message for [UpdateCmEnrollment][].
Instance Attribute Summary collapse
-
#cm_enrollment ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CmEnrollment
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#cm_enrollment ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::CmEnrollment
Returns Required. The Compliance Manager enrollment to update.
The name field is used to identify the settings that you want to update.
32 33 34 35 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb', line 32 class UpdateCmEnrollmentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. The list of fields that you want to update.
32 33 34 35 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/cm_enrollment_service.rb', line 32 class UpdateCmEnrollmentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |