Class: Google::Cloud::CloudSecurityCompliance::V1::UpdateFrameworkRequest
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::UpdateFrameworkRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb
Overview
The request message for [UpdateFramework][].
Instance Attribute Summary collapse
-
#framework ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Required.
-
#major_revision_id ⇒ ::Integer
Optional.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#framework ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::Framework
Returns Required. The resource that is being updated.
115 116 117 118 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 115 class UpdateFrameworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#major_revision_id ⇒ ::Integer
Returns Optional. The major version ID of the framework to update.
115 116 117 118 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 115 class UpdateFrameworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. A field mask is used to specify the fields to be overwritten in
the framework resource by the update. The fields specified in the
update_mask are relative to the resource, not the full request. A field
is overwritten if it is in the mask. If you don't provide a mask then all
fields present in the request will be overwritten.
115 116 117 118 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/config.rb', line 115 class UpdateFrameworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |