Class: Google::Cloud::CloudSecurityCompliance::V1::Validation
- Inherits:
-
Object
- Object
- Google::Cloud::CloudSecurityCompliance::V1::Validation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb
Overview
The validation of the parameter.
Instance Attribute Summary collapse
-
#allowed_values ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::AllowedValues
The permitted set of values for the parameter.
-
#int_range ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::IntRange
The permitted range for numeric parameters.
-
#regexp_pattern ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::RegexpPattern
The regular expression for string parameters.
Instance Attribute Details
#allowed_values ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::AllowedValues
Returns The permitted set of values for the parameter.
Note: The following fields are mutually exclusive: allowed_values, int_range, regexp_pattern. If a field in that set is populated, all other fields in the set will automatically be cleared.
291 292 293 294 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 291 class Validation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#int_range ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::IntRange
Returns The permitted range for numeric parameters.
Note: The following fields are mutually exclusive: int_range, allowed_values, regexp_pattern. If a field in that set is populated, all other fields in the set will automatically be cleared.
291 292 293 294 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 291 class Validation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#regexp_pattern ⇒ ::Google::Cloud::CloudSecurityCompliance::V1::RegexpPattern
Returns The regular expression for string parameters.
Note: The following fields are mutually exclusive: regexp_pattern, allowed_values, int_range. If a field in that set is populated, all other fields in the set will automatically be cleared.
291 292 293 294 |
# File 'proto_docs/google/cloud/cloudsecuritycompliance/v1/common.rb', line 291 class Validation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |